(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17104,        557]
NotebookOptionsPosition[     12681,        429]
NotebookOutlinePosition[     14373,        467]
CellTagsIndexPosition[     14330,        464]
WindowTitle->Obtuse Package - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "GuideColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Obtuse/guide/Obtuse"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[CellGroupData[{

Cell["Obtuse Package", "GuideTitle",
 CellID->942062912],

Cell["\<\
This package contains routines and tools for obtuse angle shadowing networks \
and distance-based interpolation between scattered, multidimensional points. \
Four variants of distance-based interpolation can be compared with \
(coordinate-based) 2D Delaunay interpolation.\
\>", "GuideAbstract",
 CellID->2001916300],

Cell[CellGroupData[{

Cell["Distance Matrix", "GuideFunctionsSubsection",
 CellID->184592843],

Cell[TextData[{
 Cell[TextData[ButtonBox["DirectedDistanceMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/DirectedDistanceMatrix"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " computes the symmetric or asymmetric matrix of distances or dissimilarity \
coefficients"
}], "GuideText",
 CellID->568804827]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obtuse-angle-shadowing networks", "GuideFunctionsSubsection",
 CellID->23917746],

Cell[TextData[{
 Cell[TextData[ButtonBox["ConnectionList",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/ConnectionList"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 "  gives ",
 "a list of connected point pairs according to the obtuse-angle-shadowing rule"
}], "GuideText",
 CellID->203374175],

Cell["\t", "GuideDelimiterSubsection",
 CellID->664787802]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Point network tools,",
 " ",
 Cell[BoxData[
  RowBox[{
  "compatible", " ", "with", " ", "the", " ", "graph", " ", "objects", " ", 
   "in", " ", "the", " ", 
   StyleBox[
    ButtonBox[
     RowBox[{"Graph", " ", "Utilities", " ", "Package"}],
     BaseStyle->{"Link", "GuideFunctionsSubsection"},
     ButtonData->"paclet:GraphUtilities/guide/GraphUtilitiesPackage"], 
    "GuideFunctionsSubsection"]}]],
  Editable->True,
  FontFamily->"Verdana",
  GridBoxOptions->{
  GridBoxBackground->{
   "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
    "RowsIndexed" -> {}}}]
}], "GuideFunctionsSubsection",
 CellID->632855842],

Cell[TextData[{
 Cell[TextData[ButtonBox["ConnectedFrom",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/ConnectedFrom"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " gives a list of numbers for those points which have connections from a \
given point."
}], "GuideText",
 CellID->588782072],

Cell[TextData[{
 Cell[TextData[ButtonBox["ConnectedNeighbors",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/ConnectedNeighbors"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 "gives a list of numbers for those points which are connected to or from a \
given point"
}], "GuideText",
 CellID->1463276848],

Cell[TextData[{
 Cell[TextData[ButtonBox["ConnectedTo",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/ConnectedTo"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " gives a list of numbers for those points which have connections to a given \
point."
}], "GuideText",
 CellID->3617127],

Cell[TextData[{
 Cell[TextData[ButtonBox["FriendCountList",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/FriendCountList"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " sorts the points according to how many connections they have."
}], "GuideText",
 CellID->473847811],

Cell[TextData[{
 Cell[TextData[ButtonBox["FriendsFromList",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/FriendsFromList"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " sorts the points according to which points they have connections from."
}], "GuideText",
 CellID->249629751],

Cell[TextData[{
 Cell[TextData[ButtonBox["FriendsList",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/FriendsList"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " ",
 "sorts the points according to which points they have connections from or to."
}], "GuideText",
 CellID->96788213],

Cell[TextData[{
 Cell[TextData[ButtonBox["FriendsToList",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/FriendsToList"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 "  sorts the points according to which points they have connections to."
}], "GuideText",
 CellID->637301445],

Cell["\t", "GuideDelimiterSubsection",
 CellID->311258892]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation methods and tools", "GuideFunctionsSubsection",
 CellID->164840874],

Cell[TextData[{
 Cell[TextData[{
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodDelaunay"],
  ButtonBox[",",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodDelaunay"],
  ButtonBox["Method",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodDelaunay"],
  ButtonBox["\[Rule]",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodDelaunay"],
  ButtonBox["\"Delaunay\"",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodDelaunay"]
 }], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " 2D scattered point ",
 "interpolation utilizing ",
 ButtonBox["Delaunay triangulation",
  BaseStyle->"Link",
  ButtonData->"paclet:ComputationalGeometry/ref/DelaunayTriangulation"]
}], "GuideText",
 CellID->527669964],

Cell[TextData[{
 Cell[TextData[{
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"],
  ButtonBox[",",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"],
  ButtonBox["Method",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"],
  ButtonBox["\[Rule]",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"],
  ButtonBox["\"Voronoi\"",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"]
 }], "InlineFunctionSans"],
 " returns the function value of the nearest control point from the \
interpolation point."
}], "GuideText",
 CellID->337329498],

Cell[TextData[{
 Cell[TextData[{
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
  ButtonBox[",",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
  ButtonBox["Method",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
  ButtonBox["\[Rule]",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
  ButtonBox["\"ObtuseAngle\"",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"]
 }], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " Multidimensional scattered point interpolation, using obtuse angle \
shadowing networks. "
}], "GuideText",
 CellID->27401201],

Cell[TextData[{
 Cell[TextData[ButtonBox["InterpolationCoefficients",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/InterpolationCoefficients"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " is used in the algorithm for obtuse angle interpolation, and ",
 "gives a vector of interpolation coefficients."
}], "GuideText",
 CellID->274827049],

Cell[TextData[{
 Cell[TextData[{
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"],
  ButtonBox[",",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"],
  ButtonBox["Method",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"],
  ButtonBox["\[Rule]",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"],
  ButtonBox["\"RBF\"",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"]
 }], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " Multidimensional scattered point interpolation, using ",
 ButtonBox["radial basis functions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Radial_basis_function"], None}],
 ". "
}], "GuideText",
 CellID->302511692],

Cell[TextData[{
 Cell[TextData[{
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"],
  ButtonBox[",",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"],
  ButtonBox["Method",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"],
  ButtonBox["\[Rule]",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"],
  ButtonBox["\"Shepard\"",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"]
 }], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " Multidimensional scattered point interpolation, using ",
 ButtonBox["the Shepard method",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Shepard%27s_method"], None}],
 ". "
}], "GuideText",
 CellID->42849076],

Cell["\t", "GuideDelimiterSubsection",
 CellID->72449339]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options", "GuideFunctionsSubsection",
 CellID->725985378],

Cell[TextData[Cell[TextData[ButtonBox["ConnectionsToExclude",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/ConnectionsToExclude"]], "InlineFunctionSans"]], \
"GuideText",
 CellID->94911097],

Cell[TextData[Cell[TextData[ButtonBox["CutoffRadius",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/CutoffRadius"]], "InlineFunctionSans"]], "GuideText",
 CellID->314546950],

Cell[TextData[Cell[TextData[ButtonBox["CutoffValue",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/CutoffValue"]], "InlineFunctionSans"]], "GuideText",
 CellID->258823853],

Cell[TextData[Cell[TextData[ButtonBox["DistanceFunction",
 BaseStyle->"NewInVersionLink",
 ButtonData->"paclet:ref/DistanceFunction"]], "InlineFunctionSans",
 Background->Dynamic[
   If[CurrentValue[{TaggingRules, "ModificationHighlight"}] === True, 
    RGBColor[0.92, 1, 0.59], None]]]], "GuideText",
 CellID->31422740],

Cell[TextData[Cell[TextData[ButtonBox["NeighborLevel",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/NeighborLevel"]], "InlineFunctionSans"]], "GuideText",
 CellID->374702287],

Cell[TextData[Cell[TextData[ButtonBox["RadialBasisFunction",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/RadialBasisFunction"]], "InlineFunctionSans"]], \
"GuideText",
 CellID->189214112],

Cell[TextData[Cell[TextData[ButtonBox["ShepardPower",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/ShepardPower"]], "InlineFunctionSans"]], "GuideText",
 CellID->387495486],

Cell[TextData[Cell[TextData[ButtonBox["SmoothenDistance",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/SmoothenDistance"]], "InlineFunctionSans"]], "GuideText",
 CellID->130751841],

Cell[TextData[Cell[TextData[ButtonBox["Type",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/Type"]], "InlineFunctionSans"]], "GuideText",
 CellID->217677082]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIALS", "GuideTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["Obtuse Angle Shadowing Networks",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Obtuse Angle Shadowing Networks"]], "GuideTutorial",
 CellID->806871991],

Cell[TextData[ButtonBox["Scattered Point Interpolation",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Scattered Point Interpolation"]], "GuideTutorial",
 CellID->1885805579],

Cell[TextData[ButtonBox["Interpolation interactive demo",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Interpolation interactive demo"]], "GuideTutorial",
 CellID->699469456]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Obtuse Package - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2010, 5, 20, 23, 18, 21.8592914}", "context" -> "Obtuse`", 
    "keywords" -> {
     "Obtuse Angle Shadowing", "Obtuse Angle", "Shadowing", "Distance matrix",
       "Connected Points", "Network", "Neighbors", "Scattered Points", 
      "n-dimensional", "Multidimensional", "Interpolation", 
      "Obtuse Angle Interpolation", "RBF", "Radial Basis Function", "Shepard",
       "Delaunay", "Voronoi", "machine learning", "connection", 
      "neighborhood", "correlated points", "associated", "point set", 
      "distance-based"}, "index" -> True, "label" -> "Obtuse Guide", 
    "language" -> "en", "paclet" -> "Obtuse", "status" -> "None", "summary" -> 
    "This package contains routines and tools for obtuse angle shadowing \
networks and distance-based interpolation between scattered, multidimensional \
points. Three variants of distance-based interpolation can be compared with \
(coordinate-based) 2D Delaunay interpolation.", "synonyms" -> {}, "title" -> 
    "Obtuse Package", "type" -> "Guide", "uri" -> 
    "Obtuse/guide/ObtusePackage"}, "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[595, 21, 75, 1, 3, "GuideColorBar"],
Cell[673, 24, 178, 5, 19, "LinkTrail"],
Cell[CellGroupData[{
Cell[876, 33, 56, 1, 86, "GuideTitle",
 CellID->942062912],
Cell[935, 36, 326, 6, 100, "GuideAbstract",
 CellID->2001916300],
Cell[CellGroupData[{
Cell[1286, 46, 71, 1, 28, "GuideFunctionsSubsection",
 CellID->184592843],
Cell[1360, 49, 350, 10, 34, "GuideText",
 CellID->568804827]
}, Open  ]],
Cell[CellGroupData[{
Cell[1747, 64, 86, 1, 28, "GuideFunctionsSubsection",
 CellID->23917746],
Cell[1836, 67, 331, 9, 20, "GuideText",
 CellID->203374175],
Cell[2170, 78, 58, 1, 21, "GuideDelimiterSubsection",
 CellID->664787802]
}, Open  ]],
Cell[CellGroupData[{
Cell[2265, 84, 660, 20, 28, "GuideFunctionsSubsection",
 CellID->632855842],
Cell[2928, 106, 326, 9, 20, "GuideText",
 CellID->588782072],
Cell[3257, 117, 338, 9, 20, "GuideText",
 CellID->1463276848],
Cell[3598, 128, 318, 9, 20, "GuideText",
 CellID->3617127],
Cell[3919, 139, 306, 8, 20, "GuideText",
 CellID->473847811],
Cell[4228, 149, 315, 8, 20, "GuideText",
 CellID->249629751],
Cell[4546, 159, 317, 9, 20, "GuideText",
 CellID->96788213],
Cell[4866, 170, 310, 8, 20, "GuideText",
 CellID->637301445],
Cell[5179, 180, 58, 1, 21, "GuideDelimiterSubsection",
 CellID->311258892]
}, Open  ]],
Cell[CellGroupData[{
Cell[5274, 186, 87, 1, 28, "GuideFunctionsSubsection",
 CellID->164840874],
Cell[5364, 189, 881, 26, 20, "GuideText",
 CellID->527669964],
Cell[6248, 217, 736, 21, 34, "GuideText",
 CellID->337329498],
Cell[6987, 240, 808, 23, 34, "GuideText",
 CellID->27401201],
Cell[7798, 265, 379, 10, 34, "GuideText",
 CellID->274827049],
Cell[8180, 277, 883, 27, 20, "GuideText",
 CellID->302511692],
Cell[9066, 306, 899, 27, 70, "GuideText",
 CellID->42849076],
Cell[9968, 335, 57, 1, 70, "GuideDelimiterSubsection",
 CellID->72449339]
}, Open  ]],
Cell[CellGroupData[{
Cell[10062, 341, 63, 1, 70, "GuideFunctionsSubsection",
 CellID->725985378],
Cell[10128, 344, 199, 5, 70, "GuideText",
 CellID->94911097],
Cell[10330, 351, 182, 4, 70, "GuideText",
 CellID->314546950],
Cell[10515, 357, 180, 4, 70, "GuideText",
 CellID->258823853],
Cell[10698, 363, 321, 6, 70, "GuideText",
 CellID->31422740],
Cell[11022, 371, 184, 4, 70, "GuideText",
 CellID->374702287],
Cell[11209, 377, 198, 5, 70, "GuideText",
 CellID->189214112],
Cell[11410, 384, 182, 4, 70, "GuideText",
 CellID->387495486],
Cell[11595, 390, 190, 4, 70, "GuideText",
 CellID->130751841],
Cell[11788, 396, 163, 3, 70, "GuideText",
 CellID->217677082]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12000, 405, 62, 1, 70, "GuideTutorialsSection",
 CellID->415694126],
Cell[12065, 408, 191, 4, 70, "GuideTutorial",
 CellID->806871991],
Cell[12259, 414, 188, 4, 70, "GuideTutorial",
 CellID->1885805579],
Cell[12450, 420, 189, 4, 70, "GuideTutorial",
 CellID->699469456]
}, Open  ]],
Cell[12654, 427, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

