(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     61729,       1943]
NotebookOptionsPosition[     52606,       1654]
NotebookOutlinePosition[     55489,       1717]
CellTagsIndexPosition[     55403,       1712]
WindowTitle->InterpolationCoefficients - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Obtuse/guide/Obtuse"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["OBTUSE PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Obtuse Angle Shadowing Networks\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Obtuse Angle Shadowing Networks"], \
"\<\"Scattered Point Interpolation\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Scattered Point Interpolation"], \
"\<\"Interpolation interactive demo\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Interpolation interactive demo"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Interpolation, Method -> \\\"ObtuseAngle\\\"\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/ref/InterpolationMethodObtuseAngle"], \
"\<\"DirectedDistanceMatrix\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/DirectedDistanceMatrix"], "\<\"DistanceMatrix\"\>":>
       Documentation`HelpLookup[
       "paclet:HierarchicalClustering/ref/DistanceMatrix"], \
"\<\"ConnectionList\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/ref/ConnectionList"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Obtuse Package\"\>":>
       Documentation`HelpLookup["paclet:Obtuse/guide/ObtusePackage"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Obtuse/ref/InterpolationCoefficients\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Obtuse/ref/InterpolationCoefficients"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://www.familydahl.se/mathematica/Obtuse/ref/\
InterpolationCoefficients.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://www.familydahl.se/mathematica/", 
             "Obtuse/ref/InterpolationCoefficients", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["InterpolationCoefficients", "ObjectName",
 CellID->1224892054],

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"InterpolationCoefficients", "[", 
       StyleBox[
        RowBox[{
        "interpolationpoint", ",", "controlpointlist", ",", "distmat", ",", 
         "conlistslist", ",", "interpolationorder", ",", 
         RowBox[{"(", "options", ")"}]}], "TI",
        FontSlant->"Italic"], "]"}]]],
     " \[LineSeparator]gives a vector of interpolation coefficients for the \
point ",
     StyleBox["interpolationpoint", "TI",
      FontSlant->"Italic"],
     " for ",
     Cell[BoxData[
      RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]]],
     ". The scalar product between this vector and the vector of function \
values in the distinct points in the ",
     StyleBox["controlpointlist", "TI",
      FontSlant->"Italic"],
     " gives the interpolated value in the point ",
     StyleBox["interpolationpoint", "TI",
      FontSlant->"Italic"],
     ". As last value in the function value list, the CutoffValue should be \
appended. For zeroth order the interpolated value is the average of the \
surrounding points.\nThe argument ",
     StyleBox["distmat", "TI"],
     " should give the distance matrix for the control points. The distance \
matrix does not need to be symmetric. \nThe argument ",
     StyleBox["conlistslist", "TI",
      FontSlant->"Italic"],
     " should be a list of connection lists with the option ",
     Cell[BoxData[
      ButtonBox["NeighborLevel",
       BaseStyle->"Link",
       ButtonData->"paclet:Obtuse/ref/NeighborLevel"]]],
     " running from 1 to ",
     StyleBox["interpolationorder", "TI"],
     ". If ",
     StyleBox["interpolationorder", "TI"],
     " is zero, ",
     Cell[BoxData[
      ButtonBox["NeighborLevel",
       BaseStyle->"Link",
       ButtonData->"paclet:Obtuse/ref/NeighborLevel"]]],
     " should be ",
     Cell[BoxData["1"]],
     ". \nThe argument ",
     StyleBox["interpolationorder", "TI"],
     " should be 0, 1, 2, or 3.\n\nIf this sounds too complicated, use the ",
     ButtonBox["Interpolation command with Method \[Rule] \"ObtuseAngle\"",
      BaseStyle->"Link",
      ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
     ",  with a simpler interface. Then this command is called indirectly. \
But please check the interactive examples below!"
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->528983214],

Cell[TextData[{
 "To use ",
 Cell[BoxData["InterpolationCoefficients"]],
 ", you first need to load the ",
 ButtonBox["Obtuse Package",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/guide/ObtusePackage"],
 " using ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Needs",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Needs"], "[", "\"\<Obtuse`\>\"", "]"}]], 
  "InlineFormula"],
 "."
}], "Notes",
 Editable->True,
 CellID->139140624],

Cell["The following options can be given:", "Notes",
 Editable->True,
 CellID->17366],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["CutoffRadius",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/CutoffRadius"], 
    ButtonBox["Infinity",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Infinity"], Cell[TextData[{
     "points separated by twice the ",
     Cell[BoxData[
      ButtonBox["CutoffRadius",
       BaseStyle->"Link",
       ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
     " or more are not connected"
    }], "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["DistanceFunction",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/DistanceFunction"], 
    ButtonBox["Automatic",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Automatic"], Cell["\<\
distance function to use in calculation of the distance matrix and the \
calculation of the distance from the interpolation point to the control \
points. Note, that the function here is expected to return the square of the \
distance. \
\>", "TableText"]},
   {Cell["      ", "TableRowIcon"], 
    ButtonBox["Type",
     BaseStyle->"Link",
     ButtonData->"paclet:Obtuse/ref/Type"], 
    ButtonBox["Directed",
     BaseStyle->"Link",
     ButtonData->"paclet:Combinatorica/ref/Directed"], Cell[TextData[{
     "the connection graph can be ",
     Cell[BoxData[
      ButtonBox["Directed",
       BaseStyle->"Link",
       ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
     " or ",
     Cell[BoxData[
      ButtonBox["Undirected",
       BaseStyle->"Link",
       ButtonData->"paclet:Combinatorica/ref/Undirected"]], "InlineFormula"]
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "3ColumnTableMod",
 Editable->True,
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True, True, True}}}},
 CellID->11410]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->441068560],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection",
 CellID->144345749],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->139566013],

Cell["Some 2D points: ", "ExampleText",
 Editable->True,
 CellID->65039657],

Cell[BoxData[
 RowBox[{
  RowBox[{"cpts", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->614368519],

Cell["Add function values in the 2D points: ", "ExampleText",
 Editable->True,
 CellID->472343579],

Cell[BoxData[
 RowBox[{
  RowBox[{"cptab", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"cpts", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"cpts", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], "]"}], "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"cpts", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", 
       RowBox[{"Length", "[", "cpts", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->27569007],

Cell["Test interpolation in one point: ", "ExampleText",
 Editable->True,
 CellID->111279482],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Interpolation", "[", 
   RowBox[{"cptab", ",", 
    RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"1.5", ",", "0.3"}], "}"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->213125124],

Cell[BoxData[
 RowBox[{"-", "0.038228589068810825`"}]], "Output",
 ImageSize->{75, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->583175814]
}, Open  ]],

Cell["Calculate the interpolation coefficients ", "ExampleText",
 Editable->True,
 CellID->430991233],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DirectedDistanceMatrix", "[", "cpts", "]"}]}], ";", 
  RowBox[{"InterpolationCoefficients", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.5", ",", "0.3"}], "}"}], ",", "cpts", ",", "dm", " ", ",", 
    RowBox[{"{", 
     RowBox[{"ConnectionList", "[", "dm", "]"}], "}"}], ",", "1"}], 
   "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->257202967],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.`", ",", "0.`", ",", "0.040537746316034136`", ",", 
   "0.32144248096157785`", ",", "0.`", ",", "0.`", ",", "0.638019772722388`", 
   ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}]], "Output",
 ImageSize->{408, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->24514952]
}, Open  ]],

Cell["\<\
Make a list of the function values, with the CutoffValue at the end.\
\>", "ExampleText",
 Editable->True,
 CellID->261730103],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Append", "[", 
  RowBox[{
   RowBox[{"cptab", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "0."}], "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->585572093],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.6300308135967543`"}], ",", "0.10166533307940279`", ",", 
   RowBox[{"-", "0.010936152708931439`"}], ",", 
   RowBox[{"-", "0.07130159268496226`"}], ",", "0.7573495631187863`", ",", 
   RowBox[{"-", "0.9549891609544963`"}], ",", "0.6279027826702307`", ",", 
   RowBox[{"-", "0.43694963328039504`"}], ",", "0.2841270871980245`", ",", 
   RowBox[{"-", "0.737518747276299`"}], ",", "0.`"}], "}"}]], "Output",
 ImageSize->{385, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->28429496]
}, Open  ]],

Cell["\<\
If we now take the scalar products of these two vectors, we should obtain the \
interpolated value again.\
\>", "ExampleText",
 Editable->True,
 CellID->24688962],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"InterpolationCoefficients", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.5", ",", "0.3"}], "}"}], ",", "cpts", ",", "dm", " ", ",", 
    RowBox[{"{", 
     RowBox[{"ConnectionList", "[", "dm", "]"}], "}"}], ",", "1"}], "]"}], 
  ".", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"cptab", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "0."}], "]"}]}]], "Input",
 CellLabel->"In[7]:=",
 CellID->420502598],

Cell[BoxData[
 RowBox[{"-", "0.038228589068810825`"}]], "Output",
 ImageSize->{75, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->157324239]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData["InterpolationCoefficients"]],
 " is a part of the algorithm for ",
 Cell[BoxData[
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"]]],
 " with ",
 Cell[BoxData[
  RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]]],
 ". However, the same vector, apart from the ending CutoffValue value, can \
also be obtained by entering the ",
 ButtonBox["IdentityMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IdentityMatrix"],
 " as a list of function values. Note that the function values for \
Interpolation does not need to be scalars, they can also be vectors or other \
objects. With this method, the interpolation coefficients could be found for \
any of the ",
 Cell[BoxData[
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"]]],
 " methods."
}], "ExampleText",
 Editable->True,
 CellID->441174469],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Interpolation", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"cpts", ",", 
       RowBox[{"IdentityMatrix", "[", 
        RowBox[{"Length", "[", "cpts", "]"}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"1.5", ",", "0.3"}], "}"}], "]"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->215301201],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.`", ",", "0.`", ",", "0.040537746316034136`", ",", 
   "0.32144248096157785`", ",", "0.`", ",", "0.`", ",", "0.638019772722388`", 
   ",", "0.`", ",", "0.`"}], "}"}]], "Output",
 ImageSize->{383, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->1044158401]
}, Open  ]],

Cell[TextData[{
 "Here is another way to see the interpolation coefficients: Let the function \
values be ",
 Cell[BoxData["f1"]],
 ", ",
 Cell[BoxData["f2"]],
 ", ..., f10"
}], "ExampleText",
 Editable->True,
 CellID->170771701],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Interpolation", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"cpts", ",", 
       RowBox[{"{", 
        RowBox[{
        "f1", ",", "f2", ",", "f3", ",", "f4", ",", "f5", ",", "f6", ",", 
         "f7", ",", "f8", ",", "f9", ",", "f10"}], "}"}]}], "}"}], "]"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"1.5", ",", "0.3"}], "}"}], "]"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->74706903],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.`", " ", "f1"}], "+", 
  RowBox[{"0.`", " ", "f10"}], "+", 
  RowBox[{"0.`", " ", "f2"}], "+", 
  RowBox[{"0.`", " ", "f3"}], "+", 
  RowBox[{"0.040537746316034136`", " ", "f4"}], "+", 
  RowBox[{"0.32144248096157785`", " ", "f5"}], "+", 
  RowBox[{"0.`", " ", "f6"}], "+", 
  RowBox[{"0.`", " ", "f7"}], "+", 
  RowBox[{"0.638019772722388`", " ", "f8"}], "+", 
  RowBox[{"0.`", " ", "f9"}]}]], "Output",
 ImageSize->{564, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->24307474]
}, Open  ]],

Cell[TextData[{
 "If we call the function ",
 Cell[BoxData[
  ButtonBox["Interpolation",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"]]],
 " with ",
 Cell[BoxData[
  RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]]],
 " without specifying the point, we get back a function containing an \
InterpolationCoefficients function call"
}], "ExampleText",
 Editable->True,
 CellID->12063605],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ff", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"cptab", ",", 
    RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}]}], "]"}]}]], "Input",
 CellLabel->"In[10]:=",
 CellID->122123586],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InterpolationCoefficients", "[", 
    RowBox[{"#1", ",", "pts$325245", ",", "dm$325245", ",", 
     RowBox[{"{", "cl$325245", "}"}], ",", "1", ",", 
     RowBox[{"Method", "\[Rule]", "\<\"ObtuseAngle\"\>"}]}], "]"}], ".", 
   "fvalues$325245"}], "&"}]], "Output",
 ImageSize->{466, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->112603805]
}, Open  ]],

Cell["\<\
If you are curious, you might inspect various part of the output above.\
\>", "ExampleText",
 Editable->True,
 CellID->219921164]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Options",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(3)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->2061341341],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   StyleBox["CutoffRadius",
    Editable->True],
   Cell["", "ExampleCount"],
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->20803],

Cell[TextData[{
 "If the distance between two point is larger or equal to 2 times the ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 " value, the two points are not connected. Then the distance matrix element \
should be larger or equal to 4 times the squared ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 " value. The value ",
 Cell[BoxData[
  ButtonBox["Infinity",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Infinity"]], "InlineFormula"],
 " is default.\[LineSeparator]The interpolated value in points more distant \
than ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 " from all control points will take the value defined by the option ",
 Cell[BoxData[
  ButtonBox["CutoffValue",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffValue"]], "InlineFormula"],
 ". The interpolated value in points more distant than half the ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 " will be affected to some extent by ",
 Cell[BoxData[
  ButtonBox["CutoffValue",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffValue"]], "InlineFormula"],
 " - the transition is continuous."
}], "ExampleText",
 Editable->True,
 CellID->119855387],

Cell[TextData[{
 "The examples below have their counterpart in the corresponding place in the \
help for ",
 ButtonBox["Interpolation with Method \[Rule] \"ObtuseAngle\"",
  BaseStyle->"Link",
  ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
 ". "
}], "ExampleText",
 Editable->True,
 CellID->106862588],

Cell[TextData[{
 "Let us look at a one-point control point list, and vary the position of the \
interpolation point with fixed value of the ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 ". "
}], "ExampleText",
 Editable->True,
 CellID->96636081],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->121842770],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InterpolationCoefficients", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", "0."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0.", ",", "0."}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "0.", "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "}"}], "}"}], ",", "1", ",", 
     RowBox[{"CutoffRadius", "\[Rule]", "1"}]}], "]"}], "&"}], "[", "0.5", 
  "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->111335159],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 ImageSize->{43, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->18894155]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InterpolationCoefficients", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.5", ",", "0."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "0.`"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "0.`", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "}"}], "}"}], ",", "1", ",", 
   RowBox[{"CutoffRadius", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->26998722],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 ImageSize->{43, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->181715413]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"InterpolationCoefficients", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", "0."}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.", ",", "0."}], "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", "0.", "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", "}"}], "}"}], ",", "1", ",", 
        RowBox[{"CutoffRadius", "\[Rule]", "1"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "&"}], "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "2"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->165042920],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3cFqE0Ecx/GAT+Jr9DF8hAihPWgvetGLXvQa9K537aGgRIQKouBJWpAW
xAjSQ0kPFqHFQ0GI/6SbNJvMP5uZzOxMMt8PrbUpnf1bf92ZncxObja3bzVv
NBqNO/L+Vt4Hf+8DABBWp9UY2Gh3jV+YfRyZ6LbbncFHCUI5BfJAqzP8SDpy
N5WBbntjGA3CgU6riML484YxG42RestDNKOeZfIR83mDVGRFYjD83++0J/sO
ZbxBNvJRXKUMFVm47kwM1yl0KNAQDGjIBjT0KdAQDGjIBjRkAxrGG9AQDGjI
Rk667Y3RnKjxK43pOXPikZPrJ9YmlZ9fKRCMzJiyUZw0ph8nG5kxnzeKr5Tj
wfqNzOjZGHytxXP0GZuXjakFYWQjK+WF5sX6jWK4MTPgoEOBhmBAQzagoU+B
hmBAQzagIRvQMN6AhmBAQzZyoq7f4L42mJ9P4X5YDBiywX30GDJko3L/je27
b5Z8e/rk4+Xlvzr/nbBnd9442D/x8vbyxdfnz77U+e+EvWjjDTl1vOt899gg
/DKu3+jXcp0ifcrW5m73x29fDSIi72PRXu/8dnPn4uLSb7OoX4jrlM+ffj18
8N57s6hZoLkvGZfKm/dmUadw8xtyVSsXL4EaRw3CZePs7K8MPOTPQO0jtKDz
onLeuH+vw4TYigr9XNvrV9+YEFtRNTyfItcscuUS+ijwroZsXFxcbm3uHh//
CX0gVFJfJyXe/hsSDIkHE2KR6a+TEnf/DSbEolNfJyWB/TeYEItLW6dRiL3/
BhNiEVW+vlLc/TdkyHG7udPrndd5UBSqXpct+v4bR4encvZgQiyK8nVKivtv
MCG2EmKtJX78aO/D3s8oh8aCYmVD+hQZeDAhlrKI9yBIMCQeDDySFfe+NulW
pHOJdXTMF/3eJRmUytA0bg0wip4N6VPkklYubOOWgVkp3Cvd651vbe6yQiw1
0YNx5WD/RM4esatASSLZ6DMhlp4U+pQxVoglxWMwlm9qPCGWVFXZmvrRRf/0
akIsehmr8mmI5DewdkKExHubyzs6PPW1K8jav4VbhZtmNpCCQKcjrAGCAQ3Z
gMY5G1Z3SM1lt1muW1P2VZV3xlqqKrUp66pGKzt9VFXNcbxheYdUFYvN61ya
sq+q2253iiLKR7evSm3K4WfV7RZ7uE215PizquB23rC9Q2rx9qoPYd+Ua1WG
g7tWZfoO56pGafNS1Rxu2bC9Q6qKxWa5Dk25VtWfuWPDuSpDU25VGQO1RFXz
uPUptndILd7e4odYvCnXqmZ/Qd1/Q2ebcq5qMgtLVjWf41jU8g6pKsHHGw5V
SUPDA5cHBU5VmZtyqqpor5XueKNveYfUIk0tuFmuQ1MOVRXtXH+Xe1VaU0tU
NT64dVUJ7r+BJKS6/waiS3n/DcSV+P4bqMnkKGc0jkh8/w3ElPz+G4go/f03
sBIIBjRkAxqyAQ3jDWgIBjRkAxr6FGgIBjRkIyd2S/rpUzIT7fXokTyLpblk
IzMWS/pZv7GeTOs3hjwu6cea8bikH2vF45J+AACQuf86NJP7
    "], {{0, 109}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 109},
  PlotRange->{{0, 180}, {0, 109}}]], "Output",
 ImageSize->{184, 109},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->59627168]
}, Open  ]],

Cell[TextData[{
 ButtonBox["InterpolationOrder",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/InterpolationOrder"],
 " set to three:"
}], "ExampleText",
 Editable->True,
 CellID->397005150],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"InterpolationCoefficients", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", "0."}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.", ",", "0."}], "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", "0.", "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", "}"}]}], "}"}], ",", "3", ",", 
        RowBox[{"CutoffRadius", "\[Rule]", "1"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "&"}], "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "2"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->4284633],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3U9rE0EcxvGAr8S30TchCuJBvKQQ2oPtRS96aS96UQh6aS968A+oPVQq
EaGCWBAL0oK0IF1BKpT20CIYPASEOombJpvML5uZ7M5Mst8PKbUJnZnWp7Oz
uzOT8+X5S+VzpVLpuvp4oz6a/z4FACBftUqpaaoaaV/ofx4FEVWrteZnFYRk
CtQTlVrrM+koup4MRNWpVjQIB2qVOApnX5e02Si1uW0evGkfWbqf0fcbpKJQ
VAxa//u1avexQxhvkI3iiM9SWuIsdA4mmvMUDiiQEAxIyAYkHFMgIRiQkA1I
yAYkjDcgIRiQkI0iiapT7Wui2ldKvdfMiUeRdG6sdUveX4kRjILRZSPuNHqf
JxsFo+834leS8WD+RsHI2Wi+VuEefYENykbPhDCyUSjJiebx/I14uNE34OCA
AgnBgIRsQMIxBRKCAQnZgIRsQMJ4AxKCAQnZKBJx/gbr2qC/n8J6WDRpssE6
erRospG6/8b83Fomj7t3Pmx8/OHwh4URs35je+sgw8fb2rfbt97dvFGr1xsu
f2YMx/94Y/PzT9WHEI/QaOdvnDo/T1F9iIpHo/E3j8LhQK5j0WdPt5eXNvMr
H7nK+zxldmZ1d+co1yqQk7yvfUV7x9PllfzKR34cXN9Qpy2c1Y4jB9mg6xhT
bq6L0nWMIzf32ug6xpGz+ynzc2vbWwdu6kImnGVDHVPUkcVNXZCI75Pie/+N
ixeenJz8cVMXNOT3SfG+/waXSf0S3yclgP03VKdx5fJz7rD4Is3TiPnef2Nx
Yf39+nc3daFH6vsr+d1/Y3fnaHZm1WWN6Eh7Xzbv+29Ml1eivWPHleK/5HlK
cPtvvF7dvX9vw2WNsOO+31BjUXUyy5Sw8HmZZ/7wwadXL7+6rxdGvGRDncyq
rsN9vTDia10bd2bD52vtEndmw+dxXRtdR+A8rpXe3/+lug4uoQfL73pYTlhC
5jcb9Xrj2tUX3LgPk/f9N5jzE6wMg2Fd1PLS5uNHXzIpqh+bSFjr+dV5/HJx
Yf3w8Lf3ZozXl3kkv4SJk0dIMi9zFNHecbb7gUz8I7+7lqFlA+HIqTvCBCAY
kJANSKyzYbRCaiCzzXLtijJvVXJnrJFaJRZl3Kr2zM4sWpXOcrxhuEIqjcHm
dTZFmbcqqlZrcSOStZu3SizK4ncVRfEebj0lWf6uUtj1G6YrpIYvL70K86Js
W6Wp3LZVuu+wblU7bZm0agC7bJiukEpjsFmuRVG2rTrtW7Fh3SpNUXat0gZq
hFYNYndMMV0hNXx5w1cxfFG2rer/A7X/C+0vyrpV3VkYsVWDWY5FDVdIpcl9
vGHRKlVQq+LkoMCqVfqirFoVl1cJd7xxarhCapiihtws16Ioi1bF5XS+y75V
UlEjtOqscuNWBbv/BjwLeP8N+BXy/hvwK/D9N+BI9yinPY4IfP8N+BT8/hvw
KPD9NzAuCAYkZAMSsgEJ4w1ICAYkZAMSjimQEAxIyEaRmE3p55hSMP7fjx6h
MpiaSzYKxmBKP/M3JpNu/kZLhlP6MWEynNKPiZLhlH4AAFBw/wByI41F
    "], {{0, 109}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 109},
  PlotRange->{{0, 180}, {0, 109}}]], "Output",
 ImageSize->{184, 109},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->70801158]
}, Open  ]],

Cell[TextData[{
 "Let us look at a two-point control point list, with the interpolation point \
in between, with varying value of the ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 ". "
}], "ExampleText",
 Editable->True,
 CellID->4955319],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"InterpolationCoefficients", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.", ",", "0."}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.", ",", "0."}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1."}], ",", "0."}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.", ",", "4."}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4.", ",", "0."}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ConnectionList", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.", ",", "4."}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4.", ",", "0."}], "}"}]}], "}"}], ",", 
         RowBox[{"CutoffRadius", "\[Rule]", "x"}]}], "]"}], "}"}], ",", "1", 
      ",", 
      RowBox[{"CutoffRadius", "\[Rule]", "x"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "2"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->822064768],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3U9rE0EYx/EFX4lvoyAexLMoiAfxkkJoD9qLXvSiF70o7NGCtAf/gNBD
RVkRKoi9WCj20oK4glSQ9mARLB4KQn2SbNpsMk92Z7LpZne+H1LaTejs0/SX
nUkyOzndmLvUOBUEwXX5eiNfrZ8PAQAYr6gZtEyFsfGGwevhiTgMo9Z3CUI6
BXJFM2p/Jx2+68tAHE61o0E4EDWTKBxtB8ZsBF0nWx5K0+1Zeq8xHzdIhVck
Bu3/fhT29h3KeINs+CN5ltKWZOG4MzE8T6FDgYZgQEM2oKFPgYZgQEM2oCEb
0DDegIZgQEM2fBKHU93XRI23BP2vmRMPnxy/sdYr/f5KgmB4xpSN5KDRfz3Z
8Iz5uJHcko4H8zc8o2ejdVuT9+g9NiwbfRPCyIZX0hPNk/kbyXBjYMBBhwIN
wYCGbEBDnwINwYCGbEBDNqBhvAENwYCGbPhEnb/BeW0wv5/C+bBoMWSD8+jR
ZsgG62+gjeMGNIw3YGacv3HI8xRYIhjQkA1o6FOgIRjQkA1oyAY0jDegIRjQ
kA2vqJ+TwvobntM/J4X1Nzynfk4K6294T5unkWD9jbT466+Nzz9XP35fXFg/
ujy4/2HuxuuqXLY2d/P+sVmfr+Tt+hsSg/cr3+RfL/fn7Mzy2TPzcpluLMnm
ndvverPxNvoiganK5eDgX967IOtz2bxaf0MeU50wnD/3RGJw7+6KbMr9mf+x
VjPp5yk+rr+x9umH9AsXLzyV40MnDBYPLnTVKRh7e3+fP9u4cvnFrZuR9Auy
WXZF1VaPbOzs/JEDhaRi/vGa/Fx2OTVR9WzIwaGTCjlQ0HEUq7rjDUmC9CDX
rr6UVJRdSz1VNBgy2pRUSA+yv39Qdi21VblsSBikE5HRJuOKcatWn9I5XNCJ
nIyqBENGF48ersrhgmemJ6YS2dja3J1uLL1a3iq7EL9Mfp+yuLA+O7O8vf27
7EK8U2AwCm9Kuo/Oi96jNwUHfXfd5GzKgFOGnZ03xSanqknbHEfyA9TOOEJS
+gyEwQuji0kwjryhHsZ0OEINEAxoyAY0ztmwOkNqKLvFct2asq8qvTLWSFWp
TVlX1Z3ZWURV2RzHG5ZnSGWxWLzOpSn7quIwjJIi0nu3r0ptyuG+iuNkDbe+
lhzvqwxuxw3bM6Tyt5e9C/umXKsy7Ny1KtNvOFfVTVshVQ3hlg3bM6SyWCyW
69CUa1WHA2dsOFdlaMqtKmOgRqhqGLc+xfYMqfzt5d9F/qZcqxp8gLo/Qgeb
cq6qNwsjVjWc41jU8gypLGMfbzhUJQ21d5weFDhVZW7KqaqkvebkjjcOLc+Q
ytNUzsVyHZpyqCpp5/i33KvSmhqhqqOdW1fF+hswY/0NKFh/AxrW30BL7yin
O45g/Q2oWH8DOtbfQCEIBjRkAxqyAQ3jDWgIBjRkAxr6FGgIBjRkwyd2U/rp
UzzD59FDYzE1l2x4xmJKP/M36sk0f6OtwCn9qJkCp/SjVgqc0g8AADz3Hy5c
V5s=
    "], {{0, 109}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 109},
  PlotRange->{{0, 180}, {0, 109}}]], "Output",
 ImageSize->{184, 109},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->351886073]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   StyleBox["DistanceFunction",
    Editable->True],
   Cell["", "ExampleCount"],
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->48483441],

Cell[TextData[{
 "The DistanceFunction determines how to calculate the squared distance \
between the interpolation point and the control points. The ",
 Cell[BoxData[
  ButtonBox["DistanceFunction",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/DistanceFunction"]],
  Editable->True,
  GridBoxOptions->{
  GridBoxBackground->{
   "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {
     None, None, None, None, None, None, None, None, None, None, None, None, 
      None, None, None, None, None, None, None, None, None, None, {None}}, 
    "RowsIndexed" -> {}},
  GridBoxDividers->{
   "Rows" -> {{
      True, True, True, True, True, True, True, True, True, True, True, True, 
       True, True, True, True, True, True, True, True, True, True, True, 
       True}}}}],
 " setting should be the same for InterpolationCoefficients as it is when the \
",
 StyleBox["distmat", "TI"],
 " argument was calculated."
}], "ExampleText",
 Editable->True,
 CellID->210846557],

Cell[TextData[{
 "With the default setting ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["DistanceFunction",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/DistanceFunction"], "->", 
   ButtonBox["Automatic",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Automatic"]}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["DirectedDistanceMatrix",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/DirectedDistanceMatrix"]], "InlineFormula"],
 " uses the square of ",
 Cell[BoxData[
  ButtonBox["EuclideanDistance",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EuclideanDistance"]], "InlineFormula"],
 " for numeric data, ",
 Cell[BoxData[
  ButtonBox["JaccardDissimilarity",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/JaccardDissimilarity"]], "InlineFormula"],
 " for Boolean data, and ",
 Cell[BoxData[
  ButtonBox["EditDistance",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EditDistance"]], "InlineFormula"],
 " for string data. We might interpolate between words: "
}], "ExampleText",
 Editable->True,
 CellID->353197138],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->284859536],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"distmat", "=", 
   RowBox[{"DirectedDistanceMatrix", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<All\>\"", ",", "\"\<that\>\"", ",", "\"\<is\>\"", ",", 
       "\"\<gold\>\"", ",", "\"\<does\>\"", ",", "\"\<not\>\"", ",", 
       "\"\<glitter\>\"", ",", "\"\<Not\>\"", ",", "\"\<all\>\"", ",", 
       "\"\<those\>\"", ",", "\"\<who\>\"", ",", "\"\<wander\>\"", ",", 
       "\"\<are\>\"", ",", "\"\<lost\>\""}], "}"}], ",", 
     RowBox[{"DistanceFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"EditDistance", "[", 
           RowBox[{"#1", ",", "#2"}], "]"}], "^", "2"}], ")"}], "&"}], 
       ")"}]}]}], "]"}]}], ";", 
  RowBox[{"InterpolationCoefficients", "[", 
   RowBox[{"\"\<Strider\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<All\>\"", ",", "\"\<that\>\"", ",", "\"\<is\>\"", ",", 
      "\"\<gold\>\"", ",", "\"\<does\>\"", ",", "\"\<not\>\"", ",", 
      "\"\<glitter\>\"", ",", "\"\<Not\>\"", ",", "\"\<all\>\"", ",", 
      "\"\<those\>\"", ",", "\"\<who\>\"", ",", "\"\<wander\>\"", ",", 
      "\"\<are\>\"", ",", "\"\<lost\>\""}], "}"}], ",", "distmat", ",", 
    RowBox[{"{", 
     RowBox[{"ConnectionList", "[", "distmat", "]"}], "}"}], ",", "1", ",", 
    RowBox[{"Method", "\[Rule]", "\"\<ObtuseAngle\>\""}], ",", 
    RowBox[{"DistanceFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"EditDistance", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "^", "2"}], ")"}], "&"}], 
      ")"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->134670007],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0.0032446322643686376`", ",", "0", ",", "0", 
   ",", "0.1996048042874615`", ",", "0", ",", "0", ",", 
   "0.17617681892294595`", ",", "0", ",", "0.5363895379092689`", ",", 
   "0.08458420661595485`", ",", "0", ",", "0"}], "}"}]], "Output",
 ImageSize->{536, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->2633742]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   StyleBox["Type",
    Editable->True],
   Cell["", "ExampleCount"],
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellID->171530212],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["Type",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/Type"]], "InlineFormula"],
 " is defined in the Combinatorica`context and is an option for many ",
 StyleBox["Combinatorica",
  FontSlant->"Italic"],
 " functions that transform graphs. Depending on the functions it is being \
used in, it can take on values such as ",
 Cell[BoxData[
  ButtonBox["Directed",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["Undirected",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Undirected"]], "InlineFormula"],
 ", Simple, etc. For the function ConnectionList the values ",
 Cell[BoxData[
  ButtonBox["Directed",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox[
   ButtonBox["Undirected",
    BaseStyle->"Link",
    ButtonData->"paclet:Combinatorica/ref/Undirected"],
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Undirected"]], "InlineFormula"],
 " are implemented, with ",
 Cell[BoxData[
  ButtonBox["Directed",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
 " as default.\nIf the option ",
 Cell[BoxData[
  ButtonBox["Type",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/Type"]], "InlineFormula"],
 " is set to ",
 Cell[BoxData[
  ButtonBox["Directed",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
 " : The point A in the point set is NOT connected to the point B if there \
exist one other points C in the point set, such that C is connected to B and \
the angles ACB is obtuse. Further, two points in the network are NOT \
connected if the distance between them is smaller or equal to the ",
 Cell[BoxData[
  ButtonBox["SmoothenDistance",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/SmoothenDistance"]], "InlineFormula"],
 " zero or larger or equal to twice the ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 ".   \n  If the option  ",
 Cell[BoxData[
  ButtonBox["Type",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/Type"]], "InlineFormula"],
 " is set to ",
 Cell[BoxData[
  ButtonBox["Undirected",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Undirected"]], "InlineFormula"],
 ": Two points A and B in the point set are NOT connected if there exist two \
other points C and D in the point set, such that C is connected to A and D is \
connected to B and both the angles ACB and ADB are obtuse. Further, two \
points in the network are NOT connected if the distance between them is \
smaller or equal to the ",
 Cell[BoxData[
  ButtonBox["SmoothenDistance",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/SmoothenDistance"]], "InlineFormula"],
 " value or larger or equal to twice the ",
 Cell[BoxData[
  ButtonBox["CutoffRadius",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "InlineFormula"],
 ". Each connected point pair occurs only once in the returned list, with the \
lowest point number coming first.\nEven if the option ",
 Cell[BoxData[
  ButtonBox["Type",
   BaseStyle->"Link",
   ButtonData->"paclet:Obtuse/ref/Type"]], "InlineFormula"],
 " is set to ",
 Cell[BoxData[
  ButtonBox["Directed",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
 ", most connections are bidirectional. The algorithm for the case ",
 Cell[BoxData[
  ButtonBox["Directed",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
 " is somewhat simpler than the case ",
 Cell[BoxData[
  ButtonBox["Undirected",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Undirected"]], "InlineFormula"],
 ", and that is the reason to set ",
 Cell[BoxData[
  ButtonBox["Directed",
   BaseStyle->"Link",
   ButtonData->"paclet:Combinatorica/ref/Directed"]], "InlineFormula"],
 " as default. The points in the example below is chosen to emphasize the \
differences between the settings, but the change in the interpolation values \
anyway is subtle."
}], "ExampleText",
 Editable->True,
 CellID->28595840],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->85627697],

Cell[BoxData[
 RowBox[{
  RowBox[{"cpts", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.", ",", "0."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5.", ",", "0."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6.2", ",", "6.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8.", ",", "3."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.5", ",", "8"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->239715799],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cld", "=", 
  RowBox[{"ConnectionList", "[", 
   RowBox[{
    RowBox[{"DirectedDistanceMatrix", "[", "cpts", "]"}], ",", 
    RowBox[{"Type", "\[Rule]", "Directed"}]}], "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->69409248],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"5", "\[Rule]", "3"}], ",", 
   RowBox[{"3", "\[Rule]", "5"}], ",", 
   RowBox[{"4", "\[Rule]", "3"}], ",", 
   RowBox[{"3", "\[Rule]", "4"}], ",", 
   RowBox[{"4", "\[Rule]", "2"}], ",", 
   RowBox[{"2", "\[Rule]", "4"}], ",", 
   RowBox[{"2", "\[Rule]", "1"}], ",", 
   RowBox[{"1", "\[Rule]", "2"}], ",", 
   RowBox[{"1", "\[Rule]", "3"}], ",", 
   RowBox[{"5", "\[Rule]", "1"}]}], "}"}]], "Output",
 ImageSize->{427, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->274803331]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"clud", "=", 
  RowBox[{"ConnectionList", "[", 
   RowBox[{
    RowBox[{"DirectedDistanceMatrix", "[", "cpts", "]"}], ",", 
    RowBox[{"Type", "\[Rule]", "Undirected"}]}], "]"}]}]], "Input",
 CellLabel->"In[4]:=",
 CellID->483640573],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"3", "\[Rule]", "5"}], ",", 
   RowBox[{"3", "\[Rule]", "4"}], ",", 
   RowBox[{"2", "\[Rule]", "4"}], ",", 
   RowBox[{"1", "\[Rule]", "2"}], ",", 
   RowBox[{"1", "\[Rule]", "3"}]}], "}"}]], "Output",
 ImageSize->{217, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->13918836]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cptab", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.", ",", "0."}], "}"}], ",", "0."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"5.", ",", "0."}], "}"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6.2", ",", "6.2"}], "}"}], ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"8.", ",", "3."}], "}"}], ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4.5", ",", "8"}], "}"}], ",", "10"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->102398307],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ddm", "=", 
  RowBox[{"DirectedDistanceMatrix", "[", "cpts", "]"}]}]], "Input",
 CellLabel->"In[6]:=",
 CellID->95696066],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0", ",", "25.`", ",", "76.88000000000001`", ",", "72.99999999999999`", 
     ",", "84.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "25.`", ",", "0", ",", "39.88000000000001`", ",", "18.000000000000004`", 
     ",", "64.25000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "76.88000000000001`", ",", "39.88000000000001`", ",", "0", ",", 
     "13.480000000000002`", ",", "6.130000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "72.99999999999999`", ",", "18.000000000000004`", ",", 
     "13.480000000000002`", ",", "0", ",", "37.24999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "84.25`", ",", "64.25000000000001`", ",", "6.130000000000001`", ",", 
     "37.24999999999999`", ",", "0"}], "}"}]}], "}"}]], "Output",
 ImageSize->{405, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->195153713]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InterpolationCoefficients", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2."}], ",", "7."}], "}"}], ",", "cpts", ",", "ddm", ",", 
   RowBox[{"{", "cld", "}"}], ",", "1", ",", 
   RowBox[{"Type", "\[Rule]", "Directed"}]}], "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->377713507],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3065843621399177`", ",", "0", ",", "0", ",", "0", ",", 
   "0.6934156378600824`", ",", "0"}], "}"}]], "Output",
 ImageSize->{213, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->1780516]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InterpolationCoefficients", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2."}], ",", "7."}], "}"}], ",", "cpts", ",", "ddm", ",", 
   RowBox[{"{", "clud", "}"}], ",", "1", ",", 
   RowBox[{"Type", "\[Rule]", "Undirected"}]}], "]"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->21228173],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3737373737373737`", ",", "0", ",", "0", ",", "0", ",", 
   "0.6262626262626263`", ",", "0"}], "}"}]], "Output",
 ImageSize->{213, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->447584385]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox[
    RowBox[{"Interpolation", ",", " ", 
     RowBox[{"Method", " ", "->", " ", "\"\<ObtuseAngle\>\""}]}],
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/InterpolationMethodObtuseAngle"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DirectedDistanceMatrix",
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/DirectedDistanceMatrix"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["DistanceMatrix",
    BaseStyle->"Link",
    ButtonData->"paclet:HierarchicalClustering/ref/DistanceMatrix"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["ConnectionList",
    BaseStyle->"Link",
    ButtonData->"paclet:Obtuse/ref/ConnectionList"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["Obtuse Angle Shadowing Networks",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Obtuse Angle Shadowing Networks"]], "Tutorials",
 CellID->341631938],

Cell[TextData[ButtonBox["Scattered Point Interpolation",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Scattered Point Interpolation"]], "Tutorials",
 CellID->229795768],

Cell[TextData[ButtonBox["Interpolation interactive demo",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Interpolation interactive demo"]], "Tutorials",
 CellID->294894982]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["Obtuse Package",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/guide/ObtusePackage"]], "MoreAbout",
 CellID->417744279]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"InterpolationCoefficients - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2010, 5, 24, 20, 41, 16.2254381}", "context" -> "Obtuse`", 
    "keywords" -> {
     "Obtuse Angle Shadowing", "Obtuse Angle", "Shadowing", "Distance matrix",
       "Connected Points", "Network", "Neighbors", 
      "Obtuse Angle Interpolation", "distance-based"}, "index" -> True, 
    "label" -> "Obtuse Paclet Symbol", "language" -> "en", "paclet" -> 
    "Obtuse", "status" -> "None", "summary" -> 
    "InterpolationCoefficients[interpolationpoint, controlpointlist, \\ \
distmat, conlistslist, interpolationorder, (options)] gives a vector of \
interpolation coefficients for the point interpolationpoint for Method -> \
\"ObtuseAngle\". The scalar product between this vector and the vector of \
function values in the distinct points in the controlpointlist gives the \
interpolated value in the point interpolationpoint. As last value in the \
function value list, the CutoffValue should be appended. For zeroth order the \
interpolated value is the average of the surrounding points. The argument \
distmat should give the distance matrix for the control points. The distance \
matrix does not need to be symmetric. The argument conlistslist should be a \
list of connection lists with the option NeighborLevel running from 1 to \
interpolationorder. If interpolationorder is zero, NeighborLevel should be 1. \
The argument interpolationorder should be 0, 1, 2, or 3. If this sounds too \
complicated, use the Interpolation command with Method -> \"ObtuseAngle\", \
with a simpler interface. Then this command is called indirectly. But please \
check the interactive examples below!", "synonyms" -> {}, "title" -> 
    "InterpolationCoefficients", "type" -> "Symbol", "uri" -> 
    "Obtuse/ref/InterpolationCoefficients"}, "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[10415, 290, 461, 13, 45, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->441068560]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 55259, 1705}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[606, 21, 76, 1, 3, "SymbolColorBar"],
Cell[685, 24, 178, 5, 19, "LinkTrail"],
Cell[866, 31, 3721, 83, 46, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4612, 118, 68, 1, 51, "ObjectName",
 CellID->1224892054],
Cell[4683, 121, 2500, 62, 316, "Usage",
 CellID->982511436]
}, Open  ]],
Cell[CellGroupData[{
Cell[7220, 188, 580, 17, 39, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->528983214],
Cell[7803, 207, 436, 17, 70, "Notes",
 CellID->139140624],
Cell[8242, 226, 85, 2, 70, "Notes",
 CellID->17366],
Cell[8330, 230, 2048, 55, 70, "3ColumnTableMod",
 CellID->11410]
}, Closed]],
Cell[CellGroupData[{
Cell[10415, 290, 461, 13, 45, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->441068560],
Cell[CellGroupData[{
Cell[10901, 307, 148, 5, 31, "ExampleSection",
 CellID->144345749],
Cell[11052, 314, 133, 4, 28, "Input",
 CellID->139566013],
Cell[11188, 320, 75, 2, 32, "ExampleText",
 CellID->65039657],
Cell[11266, 324, 306, 11, 28, "Input",
 CellID->614368519],
Cell[11575, 337, 98, 2, 32, "ExampleText",
 CellID->472343579],
Cell[11676, 341, 693, 23, 28, "Input",
 CellID->27569007],
Cell[12372, 366, 93, 2, 32, "ExampleText",
 CellID->111279482],
Cell[CellGroupData[{
Cell[12490, 372, 270, 8, 70, "Input",
 CellID->213125124],
Cell[12763, 382, 195, 6, 70, "Output",
 CellID->583175814]
}, Open  ]],
Cell[12973, 391, 101, 2, 70, "ExampleText",
 CellID->430991233],
Cell[CellGroupData[{
Cell[13099, 397, 413, 12, 70, "Input",
 CellID->257202967],
Cell[13515, 411, 376, 10, 70, "Output",
 CellID->24514952]
}, Open  ]],
Cell[13906, 424, 136, 4, 70, "ExampleText",
 CellID->261730103],
Cell[CellGroupData[{
Cell[14067, 432, 212, 7, 70, "Input",
 CellID->585572093],
Cell[14282, 441, 593, 13, 70, "Output",
 CellID->28429496]
}, Open  ]],
Cell[14890, 457, 172, 5, 70, "ExampleText",
 CellID->24688962],
Cell[CellGroupData[{
Cell[15087, 466, 482, 15, 70, "Input",
 CellID->420502598],
Cell[15572, 483, 195, 6, 70, "Output",
 CellID->157324239]
}, Open  ]],
Cell[15782, 492, 970, 26, 70, "ExampleText",
 CellID->441174469],
Cell[CellGroupData[{
Cell[16777, 522, 448, 13, 70, "Input",
 CellID->215301201],
Cell[17228, 537, 366, 10, 70, "Output",
 CellID->1044158401]
}, Open  ]],
Cell[17609, 550, 229, 9, 70, "ExampleText",
 CellID->170771701],
Cell[CellGroupData[{
Cell[17863, 563, 526, 15, 70, "Input",
 CellID->74706903],
Cell[18392, 580, 571, 16, 70, "Output",
 CellID->24307474]
}, Open  ]],
Cell[18978, 599, 432, 13, 70, "ExampleText",
 CellID->12063605],
Cell[CellGroupData[{
Cell[19435, 616, 216, 6, 70, "Input",
 CellID->122123586],
Cell[19654, 624, 442, 12, 70, "Output",
 CellID->112603805]
}, Open  ]],
Cell[20111, 639, 139, 4, 70, "ExampleText",
 CellID->219921164]
}, Open  ]],
Cell[CellGroupData[{
Cell[20287, 648, 223, 7, 70, "ExampleSection",
 CellID->2061341341],
Cell[CellGroupData[{
Cell[20535, 659, 288, 9, 70, "ExampleSubsection",
 CellID->20803],
Cell[20826, 670, 1519, 41, 70, "ExampleText",
 CellID->119855387],
Cell[22348, 713, 321, 9, 70, "ExampleText",
 CellID->106862588],
Cell[22672, 724, 337, 10, 70, "ExampleText",
 CellID->96636081],
Cell[23012, 736, 133, 4, 70, "Input",
 CellID->121842770],
Cell[CellGroupData[{
Cell[23170, 744, 520, 17, 70, "Input",
 CellID->111335159],
Cell[23693, 763, 202, 7, 70, "Output",
 CellID->18894155]
}, Open  ]],
Cell[CellGroupData[{
Cell[23932, 775, 450, 14, 70, "Input",
 CellID->26998722],
Cell[24385, 791, 203, 7, 70, "Output",
 CellID->181715413]
}, Open  ]],
Cell[CellGroupData[{
Cell[24625, 803, 851, 26, 70, "Input",
 CellID->165042920],
Cell[25479, 831, 2064, 41, 70, "Output",
 CellID->59627168]
}, Open  ]],
Cell[27558, 875, 191, 7, 70, "ExampleText",
 CellID->397005150],
Cell[CellGroupData[{
Cell[27774, 886, 942, 29, 70, "Input",
 CellID->4284633],
Cell[28719, 917, 2072, 41, 70, "Output",
 CellID->70801158]
}, Open  ]],
Cell[30806, 961, 330, 10, 70, "ExampleText",
 CellID->4955319],
Cell[CellGroupData[{
Cell[31161, 975, 1314, 41, 70, "Input",
 CellID->822064768],
Cell[32478, 1018, 2021, 41, 70, "Output",
 CellID->351886073]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[34548, 1065, 295, 9, 70, "ExampleSubsection",
 CellID->48483441],
Cell[34846, 1076, 981, 26, 70, "ExampleText",
 CellID->210846557],
Cell[35830, 1104, 1052, 33, 70, "ExampleText",
 CellID->353197138],
Cell[36885, 1139, 133, 4, 70, "Input",
 CellID->284859536],
Cell[CellGroupData[{
Cell[37043, 1147, 1674, 41, 70, "Input",
 CellID->134670007],
Cell[38720, 1190, 442, 11, 70, "Output",
 CellID->2633742]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[39211, 1207, 284, 9, 70, "ExampleSubsection",
 CellID->171530212],
Cell[39498, 1218, 4300, 115, 70, "ExampleText",
 CellID->28595840],
Cell[43801, 1335, 132, 4, 70, "Input",
 CellID->85627697],
Cell[43936, 1341, 469, 16, 70, "Input",
 CellID->239715799],
Cell[CellGroupData[{
Cell[44430, 1361, 253, 7, 70, "Input",
 CellID->69409248],
Cell[44686, 1370, 584, 17, 70, "Output",
 CellID->274803331]
}, Open  ]],
Cell[CellGroupData[{
Cell[45307, 1392, 257, 7, 70, "Input",
 CellID->483640573],
Cell[45567, 1401, 383, 12, 70, "Output",
 CellID->13918836]
}, Open  ]],
Cell[45965, 1416, 761, 27, 70, "Input",
 CellID->102398307],
Cell[CellGroupData[{
Cell[46751, 1447, 145, 4, 70, "Input",
 CellID->95696066],
Cell[46899, 1453, 976, 27, 70, "Output",
 CellID->195153713]
}, Open  ]],
Cell[CellGroupData[{
Cell[47912, 1485, 327, 9, 70, "Input",
 CellID->377713507],
Cell[48242, 1496, 285, 9, 70, "Output",
 CellID->1780516]
}, Open  ]],
Cell[CellGroupData[{
Cell[48564, 1510, 329, 9, 70, "Input",
 CellID->21228173],
Cell[48896, 1521, 287, 9, 70, "Output",
 CellID->447584385]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49256, 1538, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[49676, 1552, 1263, 40, 70, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[50976, 1597, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[51398, 1611, 187, 4, 70, "Tutorials",
 CellID->341631938],
Cell[51588, 1617, 183, 4, 70, "Tutorials",
 CellID->229795768],
Cell[51774, 1623, 185, 4, 70, "Tutorials",
 CellID->294894982]
}, Open  ]],
Cell[CellGroupData[{
Cell[51996, 1632, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[52418, 1646, 146, 3, 70, "MoreAbout",
 CellID->417744279]
}, Open  ]],
Cell[52579, 1652, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

