(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    103582,       2438]
NotebookOptionsPosition[     99784,       2326]
NotebookOutlinePosition[    101673,       2376]
CellTagsIndexPosition[    101630,       2373]
WindowTitle->Interpolation interactive demo - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:Obtuse/guide/Obtuse"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["OBTUSE TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Related Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Obtuse Angle Shadowing Networks\"\>":>
       Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Obtuse Angle Shadowing Networks"], \
"\<\"Scattered Point Interpolation\"\>":>Documentation`HelpLookup[
       "paclet:Obtuse/tutorial/Scattered Point Interpolation"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->
         False], {"\<\"Obtuse/tutorial/Interpolation interactive demo\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["Obtuse/tutorial/Interpolation interactive demo"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://www.familydahl.se/mathematica/Obtuse/tutorial/\
Interpolation interactive demo.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://www.familydahl.se/mathematica/", 
             "Obtuse/tutorial/Interpolation interactive demo", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 GridBoxOptions->{GridBoxItemSize->{"Columns" -> {
     Scaled[0.65], {
      Scaled[0.34]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
   "RowsIndexed" -> {}}},
 CellID->1],

Cell[CellGroupData[{

Cell["Interpolation interactive demo", "Title",
 CellID->509267359],

Cell[TextData[{
 "The interactive example below of scattered point interpolation is \
interactive only in the notebook variant of this page, not in the HTML \
version. A related demonstration, which is working in the free",
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/player/download.cgi"], None}],
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/player/download.cgi"], None}],
  FontSlant->"Italic"],
 ButtonBox[" Player",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/player/download.cgi"], None}],
 ", can be downloaded at ",
 ButtonBox["http://demonstrations.wolfram.com/\
ObtuseAngleShadowingNetworksAndDistanceBasedInterpolation/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
ObtuseAngleShadowingNetworksAndDistanceBasedInterpolation/"], None}],
 "\nIn the interactive example, you might change the methods, some option \
settings and the point locations. The controls interact with each other, and \
inactive controls are hidden. For example, for the method \"Delaunay\" you do \
not see any options, because there are no additional options to interpolation \
with the Dealunay method.\nFor the function values setting \"Interpolation \
coefficients\", the contour plot shows the weight of the function value of \
the green control point in different interpolation points. This corresponds \
to putting the function value to one in the green control point, and putting \
it to zero in all other control points.\nFor the function values setting \
\"Random adjustable\", the function values are random real numbers, connected \
to the control points. A slider is provided for changing the function value \
in the green point.\nFor the function values setting \"Sin[x]Sin[y]\", the \
function value in each point is the value of Sin[x]Sin[y] in that point. If \
the control point is moved, the function value is adjusted to the new \
position.\nYou might add more control points by Alt+Click, and you can drag \
the control points around.\nThe distance function choices also require a \
little explanation. \"Automatic\" implies here the usual squared euclidean \
distance. \"Periodic symmetric\" implies the distance function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["sin", "2"], "(", "\[CapitalDelta]x", ")"}], "+", 
    RowBox[{
     SuperscriptBox["sin", "2"], "(", "\[CapitalDelta]y", ")"}]}], 
   TraditionalForm]]],
 ", and \"Periodic unsymmetrical\" implies the modulated variant ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["sin", "2"], "(", 
     RowBox[{"\[CapitalDelta]x", "+", 
      FractionBox[
       RowBox[{"sin", "(", "\[CapitalDelta]x", ")"}], "2"]}], ")"}], "+", 
    RowBox[{
     SuperscriptBox["sin", "2"], "(", 
     RowBox[{"\[CapitalDelta]y", "+", 
      FractionBox[
       RowBox[{"sin", "(", "\[CapitalDelta]y", ")"}], "2"]}], ")"}]}], 
   TraditionalForm]]],
 ". \n\"Cut with asymmetry\" means that we have a cut between {-2, 0} and \
{2,0}. Distances between points are never measured across the cut. They are \
instead measured along straight lines around the cut (passing one of the end \
points), and they are always measured counterclockwise from the first point \
to the second. \nThese peculiar distance functions have been chosen to \
\"stress-test\" the mathematical routines, but at the same time they \
illustrate the power of distance-based interpolation, which can be used not \
only in multidimensional geometry, but also in strange topologies."
}], "ExampleText",
 Editable->True,
 CellID->10355336],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`cls$$ = {
    3 -> 2, 2 -> 3, 2 -> 1, 1 -> 2, 3 -> 1, 1 -> 
     3}, $CellContext`clsupdated$$ = True, $CellContext`cpnumber$$ = 
    3, $CellContext`cpvaluelist$$ = {-0.825279330689622, \
-0.43233541171336176`, 0.5700485211487498, 0.6244832993171414, 
    0.6090903549019933, -0.17288248739740242`, 0.33381162620102556`, 
    0.04185996740790632, 0.30376673671050103`, -0.9693849307879745, 
    0.32269620349906347`, 0.30545778926193146`, 0.41079935238816967`, 
    0.261356594967463, -0.5393697727399123, -0.5505774036987652, \
-0.7015972614799186, 0.5950142020565918, 0.8206631576908339, 
    0.8999888839466377}, $CellContext`cutoffradius$$ = 
    37., $CellContext`cutoffvalue$$ = 0., $CellContext`dfnum$$ = 
    1, $CellContext`dm2$$ = {{0., 19.360000000000003`, 32.}, {
    19.360000000000003`, 0., 16.16}, {32., 16.16, 
    0.}}, $CellContext`funcvals$$ = 1, $CellContext`interpolationorder$$ = 
    1, $CellContext`method$$ = "ObtuseAngle", $CellContext`neighborlevel$$ = 
    1, $CellContext`pts$$ = {{-2., -2.}, {2.4, -2.}, {2., 
    2.}}, $CellContext`ptsf$$ = {{{-2., -2.}, 0}, {{2.4, -2.}, 0}, {{2., 2.}, 
      1}}, $CellContext`ptsold$$ = {{-2., -2.}, {2.4, -2.}, {2., 
    2.}}, $CellContext`r0$$ = 1., $CellContext`rbfnum$$ = 
    1, $CellContext`smoothendistance$$ = 0., $CellContext`sp$$ = 
    6., $CellContext`type$$ = Combinatorica`Directed, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`method$$], "ObtuseAngle", "Method"}, {
      "Delaunay", "Voronoi", "ObtuseAngle", "RBF", "Shepard"}}, {{
       Hold[$CellContext`funcvals$$], 1, "Function values"}, {
      1 -> "Interpolation coefficients", 2 -> "Random adjustable", 3 -> 
       "Sin[x]Sin[y]"}}, {{
       Hold[$CellContext`cpvaluelist$$], {-0.825279330689622, \
-0.43233541171336176`, 0.5700485211487498, 0.6244832993171414, 
       0.6090903549019933, -0.17288248739740242`, 0.33381162620102556`, 
       0.04185996740790632, 0.30376673671050103`, -0.9693849307879745, 
       0.32269620349906347`, 0.30545778926193146`, 0.41079935238816967`, 
       0.261356594967463, -0.5393697727399123, -0.5505774036987652, \
-0.7015972614799186, 0.5950142020565918, 0.8206631576908339, 
       0.8999888839466377}}, 0}, {{
       Hold[$CellContext`pts$$], {{-2., -2.}, {2.4, -2.}, {2., 2.}}}, 0}, {{
       Hold[$CellContext`cpnumber$$], 1}, 0}, {{
       Hold[$CellContext`cutoffradius$$], 37.}, 0}, {{
       Hold[$CellContext`cutoffvalue$$], 0.}, 0}, {{
       Hold[$CellContext`interpolationorder$$], 1}, 0}, {{
       Hold[$CellContext`dfnum$$], 1}, 0}, {{
       Hold[$CellContext`smoothendistance$$], 0.}, 0}, {{
       Hold[$CellContext`neighborlevel$$], 1}, 0}, {{
       Hold[$CellContext`type$$], Combinatorica`Directed}, 0}, {{
       Hold[$CellContext`r0$$], 1.}, 0}, {{
       Hold[$CellContext`rbfnum$$], 1}, 0}, {{
       Hold[$CellContext`sp$$], 6.}, 0}, {
      Hold[$CellContext`dm2$$], 0}, {
      Hold[$CellContext`cls$$], 0}, {
      Hold[$CellContext`ptsf$$], 0}, {{
       Hold[$CellContext`ptsold$$], {}}, 0}, {{
       Hold[$CellContext`clsupdated$$], False}, 0}}, Typeset`size$$ = {
    484., {344., 349.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`method$301400$$ = 
    0, $CellContext`funcvals$301401$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`cls$$ = 0, $CellContext`clsupdated$$ = 
        False, $CellContext`cpnumber$$ = 
        1, $CellContext`cpvaluelist$$ = {-0.825279330689622, \
-0.43233541171336176`, 0.5700485211487498, 0.6244832993171414, 
         0.6090903549019933, -0.17288248739740242`, 0.33381162620102556`, 
         0.04185996740790632, 0.30376673671050103`, -0.9693849307879745, 
         0.32269620349906347`, 0.30545778926193146`, 0.41079935238816967`, 
         0.261356594967463, -0.5393697727399123, -0.5505774036987652, \
-0.7015972614799186, 0.5950142020565918, 0.8206631576908339, 
         0.8999888839466377}, $CellContext`cutoffradius$$ = 
        37., $CellContext`cutoffvalue$$ = 0., $CellContext`dfnum$$ = 
        1, $CellContext`dm2$$ = 0, $CellContext`funcvals$$ = 
        1, $CellContext`interpolationorder$$ = 1, $CellContext`method$$ = 
        "ObtuseAngle", $CellContext`neighborlevel$$ = 
        1, $CellContext`pts$$ = {{-2., -2.}, {2.4, -2.}, {2., 
         2.}}, $CellContext`ptsf$$ = 
        0, $CellContext`ptsold$$ = {}, $CellContext`r0$$ = 
        1., $CellContext`rbfnum$$ = 1, $CellContext`smoothendistance$$ = 
        0., $CellContext`sp$$ = 6., $CellContext`type$$ = 
        Combinatorica`Directed}, "ControllerVariables" :> {
        Hold[$CellContext`method$$, $CellContext`method$301400$$, 0], 
        Hold[$CellContext`funcvals$$, $CellContext`funcvals$301401$$, False]},
       "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> (
       While[Length[$CellContext`cpvaluelist$$] <= Length[$CellContext`pts$$], 
         AppendTo[$CellContext`cpvaluelist$$, 
          RandomReal[{-1, 1}]]]; 
       If[$CellContext`cpnumber$$ > 
         Length[$CellContext`pts$$], $CellContext`cpnumber$$ = 
         Length[$CellContext`pts$$]]; 
       If[$CellContext`ptsold$$ =!= $CellContext`pts$$, \
$CellContext`clsupdated$$ = False; 
         Which[Length[$CellContext`pts$$] == 
           0, $CellContext`pts$$ = $CellContext`ptsold$$, 
           Length[$CellContext`pts$$] > 
           Length[$CellContext`ptsold$$], $CellContext`cpnumber$$ = 
            Length[$CellContext`pts$$]; $CellContext`ptsold$$ = \
$CellContext`pts$$, Length[$CellContext`pts$$] < 
           Length[$CellContext`ptsold$$], 
           Do[
            If[
            Part[$CellContext`pts$$, $CellContext`i] != 
             Part[$CellContext`ptsold$$, $CellContext`i], 
             Do[Part[$CellContext`cpvaluelist$$, $CellContext`j] = 
               Part[$CellContext`cpvaluelist$$, $CellContext`j + 
                 1], {$CellContext`j, $CellContext`i, 
                Length[$CellContext`pts$$]}]; Part[$CellContext`cpvaluelist$$, 
                Length[$CellContext`ptsold$$]] = 
              RandomReal[{-1, 
                1}]; $CellContext`ptsold$$ = $CellContext`pts$$; \
$CellContext`cpnumber$$ = 1], {$CellContext`i, 
             Length[$CellContext`pts$$]}], True, 
           Catch[
            Do[
             If[
             Part[$CellContext`pts$$, $CellContext`i] != 
              Part[$CellContext`ptsold$$, $CellContext`i], \
$CellContext`cpnumber$$ = $CellContext`i; $CellContext`ptsold$$ = \
$CellContext`pts$$; Throw[True]], {$CellContext`i, 
              Length[$CellContext`pts$$]}]]]]; 
       If[$CellContext`method$$ == 
         "ObtuseAngle", $CellContext`dm2$$ = 
          Obtuse`DirectedDistanceMatrix[$CellContext`pts$$, 
            DistanceFunction -> $CellContext`dfunc[$CellContext`dfnum$$]]; \
$CellContext`cls$$ = 
          Obtuse`ConnectionList[$CellContext`dm2$$, 
            Obtuse`CutoffRadius -> $CellContext`cutoffradius$$, 
            Obtuse`SmoothenDistance -> $CellContext`smoothendistance$$, 
            Combinatorica`Type -> $CellContext`type$$, 
            Obtuse`NeighborLevel -> $CellContext`neighborlevel$$]; \
$CellContext`clsupdated$$ = True]; If[
         And[
          Not[
           
           And[$CellContext`method$$ == 
            "ObtuseAngle", $CellContext`interpolationorder$$ == -1]]], 
         Switch[$CellContext`funcvals$$, 1, $CellContext`ptsf$$ = 
           Transpose[{$CellContext`pts$$, 
              Part[
               IdentityMatrix[
                Length[$CellContext`pts$$]], $CellContext`cpnumber$$]}], 
           2, $CellContext`ptsf$$ = Transpose[{$CellContext`pts$$, 
              Take[$CellContext`cpvaluelist$$, 
               Length[$CellContext`pts$$]]}], 3, $CellContext`ptsf$$ = 
           Map[{#, Sin[
                Part[#, 1]] Sin[
                Part[#, 2]]}& , $CellContext`pts$$]]; $CellContext`func4 = 
          Interpolation[$CellContext`ptsf$$, Method -> $CellContext`method$$, 
            Obtuse`CutoffRadius -> $CellContext`cutoffradius$$, 
            Obtuse`CutoffValue -> $CellContext`cutoffvalue$$, 
            DistanceFunction -> $CellContext`dfunc[$CellContext`dfnum$$], 
            InterpolationOrder -> $CellContext`interpolationorder$$, 
            Obtuse`SmoothenDistance -> $CellContext`smoothendistance$$, 
            Obtuse`NeighborLevel -> $CellContext`neighborlevel$$, 
            Combinatorica`Type -> $CellContext`type$$, 
            Obtuse`RadialBasisFunction -> \
$CellContext`rbffunc[$CellContext`rbfnum$$, $CellContext`r0$$], 
            Obtuse`ShepardPower -> $CellContext`sp$$]]; Grid[{{
           Pane[
            Grid[{{"Green point number", 
               Manipulator[
                Dynamic[$CellContext`cpnumber$$], {1, 
                 Length[$CellContext`pts$$], 1}, ContinuousAction -> False], 
               InputField[
                Dynamic[$CellContext`cpnumber$$], FieldSize -> Tiny]}, 
              Apply[Sequence, {
                If[
                 And[$CellContext`funcvals$$ == 2, 
                  Not[
                   
                   And[$CellContext`method$$ == 
                    "ObtuseAngle", $CellContext`interpolationorder$$ == \
-1]]], {"Green point\nfunction value", 
                  Manipulator[
                   Dynamic[
                    
                    Part[$CellContext`cpvaluelist$$, \
$CellContext`cpnumber$$]], {-1, 1}, ContinuousAction -> False], 
                  InputField[
                   Dynamic[
                    
                    Part[$CellContext`cpvaluelist$$, \
$CellContext`cpnumber$$]], FieldSize -> Tiny]}, {
                  Style[" \n ", FontSize -> 13]}]}], 
              Apply[Sequence, {
                If[
                 
                 MemberQ[{
                  "Voronoi", "ObtuseAngle", "RBF", 
                   "Shepard"}, $CellContext`method$$], {"Distance\nFunction", 
                  
                  Control[{$CellContext`dfnum$$, {
                    1 -> "Automatic", 2 -> "Periodic \nsymmetric", 3 -> 
                    "Periodic \nasymmetric", 4 -> "Cut with \nasymmetry"}}], 
                  SpanFromLeft}, {}]}], 
              Apply[Sequence, {
                If[$CellContext`method$$ == "ObtuseAngle", {"CutoffRadius", 
                  Manipulator[
                   Dynamic[$CellContext`cutoffradius$$], {0, 37}, 
                   ContinuousAction -> False], 
                  InputField[
                   Dynamic[$CellContext`cutoffradius$$], FieldSize -> 
                   Tiny]}, {}]}], 
              Apply[Sequence, {
                If[
                 
                 And[$CellContext`method$$ == 
                  "ObtuseAngle", $CellContext`cutoffradius$$ < 36.002, 
                  MemberQ[{0, 1, 2, 3}, $CellContext`interpolationorder$$]], {
                 "CutoffValue", 
                  Manipulator[
                   Dynamic[$CellContext`cutoffvalue$$], {-1, 1}, 
                   ContinuousAction -> False], 
                  InputField[
                   Dynamic[$CellContext`cutoffvalue$$], FieldSize -> Tiny]}, {
                  Style[" ", FontSize -> 50]}]}], 
              Apply[Sequence, {
                
                If[$CellContext`method$$ == "ObtuseAngle", {
                 "InterpolationOrder", 
                  
                  Control[{$CellContext`interpolationorder$$, {-1 -> 
                    " No interpolation ", 0 -> " 0 ", 1 -> " 1 ", 2 -> " 2 ", 
                    3 -> " 3 "}}], SpanFromLeft}, {}]}], 
              Apply[Sequence, {
                
                If[$CellContext`method$$ == "ObtuseAngle", {
                 "SmoothenDistance", 
                  Manipulator[
                   Dynamic[$CellContext`smoothendistance$$], {0., 5}, 
                   ContinuousAction -> False], 
                  InputField[
                   Dynamic[$CellContext`smoothendistance$$], FieldSize -> 
                   Tiny]}, {}]}], 
              Apply[Sequence, {
                If[$CellContext`method$$ == "ObtuseAngle", {"NeighborLevel", 
                  Control[{$CellContext`neighborlevel$$, {1, 2, 3, 4}}], 
                  SpanFromLeft}, {}]}], 
              Apply[Sequence, {
                If[$CellContext`method$$ == "ObtuseAngle", {"Type", 
                  
                  Control[{$CellContext`type$$, {
                    Combinatorica`Directed -> "Directed", 
                    Combinatorica`Undirected -> "Undirected"}}], 
                  SpanFromLeft}, {}]}], 
              Apply[Sequence, {
                If[$CellContext`method$$ == "RBF", {"Radial\nBasis\nFunction", 
                  
                  Control[{$CellContext`rbfnum$$, {
                    1 -> "Automatic", 2 -> "Multi\nquadric", 3 -> 
                    "Inverse\nMulti\nquadric", 4 -> "Thin\nPlate\nSpline", 5 -> 
                    "Gaussian"}}], SpanFromLeft}, {}]}], 
              Apply[Sequence, {
                If[
                 
                 And[$CellContext`method$$ == "RBF", $CellContext`rbfnum$$ > 
                  1], {"r0", 
                  Manipulator[
                   Dynamic[$CellContext`r0$$], {0.01, 12.}, ContinuousAction -> 
                   False], 
                  InputField[
                   Dynamic[$CellContext`r0$$], FieldSize -> Tiny]}, {" "}]}], 
              Apply[Sequence, {
                If[$CellContext`method$$ == "Shepard", {"ShepardPower", 
                  Manipulator[
                   Dynamic[$CellContext`sp$$], {1, 10}, ContinuousAction -> 
                   False], 
                  InputField[
                   Dynamic[$CellContext`sp$$], FieldSize -> Tiny], 
                  "   "}, {}]}]}], {460, 280}]}, {
           LocatorPane[
            Dynamic[$CellContext`pts$$], 
            Show[
             Apply[Sequence, {
               If[
                Not[
                 
                 And[$CellContext`method$$ == 
                  "ObtuseAngle", $CellContext`interpolationorder$$ == -1]], 
                
                ContourPlot[$CellContext`func4[{$CellContext`x, \
$CellContext`y}] - 
                 0.0001, {$CellContext`x, (-2) Pi, 2 
                  Pi}, {$CellContext`y, (-2) Pi, 2 Pi}, 
                 ImageSize -> {400, 400}, Exclusions -> None], {}]}], 
             If[
              And[
               MemberQ[{2, 3}, $CellContext`dfnum$$], 
               
               MemberQ[{
                "Voronoi", "ObtuseAngle", "RBF", 
                 "Shepard"}, $CellContext`method$$]], 
              ListPlot[
               Join[
                Map[Mod[#, 2 Pi]& , $CellContext`pts$$], 
                Map[Mod[#, 2 Pi] + {(-2) Pi, 0}& , $CellContext`pts$$], 
                Map[Mod[#, 2 Pi] + {(-2) Pi, (-2) Pi}& , $CellContext`pts$$], 
                Map[Mod[#, 2 Pi] + {0, (-2) Pi}& , $CellContext`pts$$]], 
               PlotStyle -> {Red}, ImageSize -> {400, 400}, 
               PlotRange -> {{(-2) Pi, 2 Pi}, {(-2) Pi, 2 Pi}}, AspectRatio -> 
               1], 
              
              ListPlot[$CellContext`pts$$, PlotStyle -> {Red}, 
               ImageSize -> {400, 400}, 
               PlotRange -> {{(-2) Pi, 2 Pi}, {(-2) Pi, 2 Pi}}, AspectRatio -> 
               1]], 
             If[
              And[
               MemberQ[{2, 3}, $CellContext`dfnum$$], 
               
               MemberQ[{
                "Voronoi", "ObtuseAngle", "RBF", 
                 "Shepard"}, $CellContext`method$$]], 
              Graphics[{Green, 
                Disk[
                 Mod[
                  Part[$CellContext`pts$$, $CellContext`cpnumber$$], 2 Pi], 
                 0.1], 
                Disk[Mod[
                   Part[$CellContext`pts$$, $CellContext`cpnumber$$], 2 
                   Pi] + {(-2) Pi, 0}, 0.1], 
                Disk[Mod[
                   Part[$CellContext`pts$$, $CellContext`cpnumber$$], 2 
                   Pi] + {(-2) Pi, (-2) Pi}, 0.1], 
                Disk[Mod[
                   Part[$CellContext`pts$$, $CellContext`cpnumber$$], 2 
                   Pi] + {0, (-2) Pi}, 0.1]}], 
              Graphics[{Green, 
                Disk[
                 Part[$CellContext`pts$$, $CellContext`cpnumber$$], 0.1]}]], 
             Apply[Sequence, {
               If[$CellContext`method$$ == "Delaunay", 
                ListPlot[
                 Append[
                  Part[$CellContext`pts$$, 
                   ComputationalGeometry`ConvexHull[$CellContext`pts$$]], 
                  Part[
                   Part[$CellContext`pts$$, 
                    ComputationalGeometry`ConvexHull[$CellContext`pts$$]], 
                   1]], Joined -> True, PlotStyle -> {White}], {}]}], 
             Apply[Sequence, {
               If[
                And[$CellContext`dfnum$$ == 4, 
                 
                 MemberQ[{
                  "Voronoi", "ObtuseAngle", "RBF", 
                   "Shepard"}, $CellContext`method$$]], 
                Graphics[{Thick, Green, 
                  Line[{{-2., 0.}, {2, 0}}]}], {}]}], 
             Apply[Sequence, {
               If[
                
                And[$CellContext`clsupdated$$, $CellContext`method$$ == 
                 "ObtuseAngle"], 
                Graphics[
                 Which[
                  
                  And[$CellContext`dfnum$$ == 4, $CellContext`type$$ === 
                   Combinatorica`Undirected], {
                   Map[Which[
                    And[
                    Or[
                    And[Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2] >= 0, Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] < 0], 
                    And[Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2] < 0, Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] >= 0]], ((Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 1] Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] - Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2] Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 1])/(Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] - Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2]))^2 < 4], 
                    Line[{
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], {-2, 0}, 
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], {2, 0}, 
                    Part[$CellContext`pts$$, 
                    Part[#, 1]]}], True, 
                    Line[{
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 
                    Part[$CellContext`pts$$, 
                    Part[#, 2]]}]]& , $CellContext`cls$$]}, 
                  
                  And[$CellContext`dfnum$$ == 4, $CellContext`type$$ === 
                   Combinatorica`Directed], {
                   Map[Which[
                    And[Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2] >= 0, Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] < 0, ((Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 1] Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] - Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2] Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 1])/(Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] - Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2]))^2 < 4], 
                    Arrow[{
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], {-2, 0}, 
                    Part[$CellContext`pts$$, 
                    Part[#, 2]]}], 
                    And[Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2] < 0, Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] >= 0, ((Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 1] Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] - Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2] Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 1])/(Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 2]], 2] - Part[
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 2]))^2 < 4], 
                    Arrow[{
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], {2, 0}, 
                    Part[$CellContext`pts$$, 
                    Part[#, 2]]}], True, 
                    Arrow[{
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 
                    Part[$CellContext`pts$$, 
                    
                    Part[#, 
                    2]]}]]& , $CellContext`cls$$]}, $CellContext`type$$ === 
                  Combinatorica`Undirected, {
                   Map[Line[{
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 
                    Part[$CellContext`pts$$, 
                    Part[#, 2]]}]& , $CellContext`cls$$]}, True, {
                   Map[Arrow[{
                    Part[$CellContext`pts$$, 
                    Part[#, 1]], 
                    Part[$CellContext`pts$$, 
                    Part[#, 2]]}]& , $CellContext`cls$$]}]], {}]}]], 
            LocatorAutoCreate -> True, ContinuousAction -> False], 
           SpanFromLeft, SpanFromLeft}}]), 
      "Specifications" :> {{{$CellContext`method$$, "ObtuseAngle", 
          "Method"}, {
         "Delaunay", "Voronoi", "ObtuseAngle", "RBF", 
          "Shepard"}}, {{$CellContext`funcvals$$, 1, "Function values"}, {
         1 -> "Interpolation coefficients", 2 -> "Random adjustable", 3 -> 
          "Sin[x]Sin[y]"}}, {{$CellContext`cpvaluelist$$, \
{-0.825279330689622, -0.43233541171336176`, 0.5700485211487498, 
          0.6244832993171414, 0.6090903549019933, -0.17288248739740242`, 
          0.33381162620102556`, 0.04185996740790632, 
          0.30376673671050103`, -0.9693849307879745, 0.32269620349906347`, 
          0.30545778926193146`, 0.41079935238816967`, 
          0.261356594967463, -0.5393697727399123, -0.5505774036987652, \
-0.7015972614799186, 0.5950142020565918, 0.8206631576908339, 
          0.8999888839466377}}, 0, ControlType -> 
         None}, {{$CellContext`pts$$, {{-2., -2.}, {2.4, -2.}, {2., 2.}}}, 0, 
         ControlType -> None}, {{$CellContext`cpnumber$$, 1}, 0, ControlType -> 
         None}, {{$CellContext`cutoffradius$$, 37.}, 0, ControlType -> 
         None}, {{$CellContext`cutoffvalue$$, 0.}, 0, ControlType -> 
         None}, {{$CellContext`interpolationorder$$, 1}, 0, ControlType -> 
         None}, {{$CellContext`dfnum$$, 1}, 0, ControlType -> 
         None}, {{$CellContext`smoothendistance$$, 0.}, 0, ControlType -> 
         None}, {{$CellContext`neighborlevel$$, 1}, 0, ControlType -> 
         None}, {{$CellContext`type$$, Combinatorica`Directed}, 0, 
         ControlType -> None}, {{$CellContext`r0$$, 1.}, 0, ControlType -> 
         None}, {{$CellContext`rbfnum$$, 1}, 0, ControlType -> 
         None}, {{$CellContext`sp$$, 6.}, 0, ControlType -> 
         None}, {$CellContext`dm2$$, 0, ControlType -> 
         None}, {$CellContext`cls$$, 0, ControlType -> 
         None}, {$CellContext`ptsf$$, 0, ControlType -> 
         None}, {{$CellContext`ptsold$$, {}}, 0, ControlType -> 
         None}, {{$CellContext`clsupdated$$, False}, 0, ControlType -> None}},
       "Options" :> {
       FrameLabel -> 
        Button["Generate a new point set!", $CellContext`randominit]}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{533., {415., 420.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({AbortProtect[
         Needs[
         "Obtuse`"]]; $CellContext`randominit := {$CellContext`pts$$ = 
           RandomReal[{-6, 6}, {2 + RandomInteger[
                PoissonDistribution[3.]], 2}]; $CellContext`cpnumber$$ = 
           RandomInteger[{1, 
              
              Length[$CellContext`pts$$]}]; $CellContext`ptsold$$ = \
$CellContext`pts$$; $CellContext`cpvaluelist$$ = 
           RandomReal[{-1, 1}, {20}]; $CellContext`clsupdated$$ = 
           False}; $CellContext`dfunc[1] := Automatic; $CellContext`dfunc[2] := 
        Sin[(Part[#2, 1] - Part[#, 1])/2]^2 + 
         Sin[(Part[#2, 2] - Part[#, 2])/2]^2& ; $CellContext`dfunc[3] := 
        Sin[(Part[#2, 1] - Part[#, 1])/2 + 
            0.5 Sin[Part[#2, 1] - Part[#, 1]]]^2 + 
         Sin[(Part[#2, 2] - Part[#, 2])/2 + 
            0.5 Sin[Part[#2, 2] - Part[#, 2]]]^2& ; $CellContext`dfunc[4] := 
        Which[
          And[
          Part[#, 2] >= 0, Part[#2, 2] < 
           0, ((Part[#, 1] Part[#2, 2] - Part[#, 2] Part[#2, 1])/(Part[#2, 2] - 
             Part[#, 2]))^2 < 4], (EuclideanDistance[#, {-2, 0}] + 
           EuclideanDistance[{-2, 0}, #2])^2, 
          And[
          Part[#, 2] < 0, Part[#2, 2] >= 
           0, ((Part[#, 1] Part[#2, 2] - Part[#, 2] Part[#2, 1])/(Part[#2, 2] - 
             Part[#, 2]))^2 < 4], (EuclideanDistance[#, {2, 0}] + 
           EuclideanDistance[{2, 0}, #2])^2, True, 
          SquaredEuclideanDistance[#, #2]]& ; $CellContext`rbffunc[1, 
          Pattern[$CellContext`r, 
           Blank[]]] := Automatic; $CellContext`rbffunc[2, 
          Pattern[$CellContext`r, 
           Blank[]]] := Sqrt[# + $CellContext`r^2]& ; $CellContext`rbffunc[3, 
          Pattern[$CellContext`r, 
           Blank[]]] := 
        1/Sqrt[# + $CellContext`r^2]& ; $CellContext`rbffunc[4, 
          Pattern[$CellContext`r, 
           Blank[]]] := 
        If[# == 0, 
          0., # (Log[#]/2 - Log[$CellContext`r])]& ; $CellContext`rbffunc[5, 
          Pattern[$CellContext`r, 
           Blank[]]] := Exp[(-#)/(2 $CellContext`r^2)]& ; Null}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellLabel->"Out[11]=",
 CellID->401249470],

Cell["More about", "Subsubsection",
 CellID->246703899],

Cell[TextData[ButtonBox["DirectedDistanceMatrix",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/DirectedDistanceMatrix"]], "TOCSection",
 CellID->122658320],

Cell[TextData[ButtonBox["ConnectionList",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/ConnectionList"]], "TOCSection",
 CellID->73792557],

Cell[TextData[ButtonBox["InterpolationMethodDelaunay",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/InterpolationMethodDelaunay"]], "Subsubsection",
 CellID->220643658],

Cell[TextData[ButtonBox["InterpolationMethodObtuseAngle",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/ref/InterpolationMethodObtuseAngle"]], "Subsubsection",
 CellID->68061551],

Cell[TextData[ButtonBox["InterpolationCoefficients",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/InterpolationCoefficients"]], "TOCSection",
 CellID->190444796],

Cell[TextData[ButtonBox["CutoffRadius",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/CutoffRadius"]], "TOCSection",
 CellID->287698431],

Cell[TextData[ButtonBox["CutoffValue",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/CutoffValue"]], "TOCSection",
 CellID->146823888],

Cell[TextData[ButtonBox["NeighborLevel",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/NeighborLevel"]], "TOCSection",
 CellID->66198734],

Cell[TextData[ButtonBox["SmoothenDistance",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/SmoothenDistance"]], "TOCSection",
 CellID->160051397],

Cell[TextData[ButtonBox["Type",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/Type"]], "TOCSection",
 CellID->27883570],

Cell[TextData[ButtonBox["InterpolationMethodRBF",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/InterpolationMethodRBF"]], "Subsubsection",
 CellID->137838945],

Cell[TextData[ButtonBox["RadialBasisFunction",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/RadialBasisFunction"]], "TOCSection",
 CellID->452924850],

Cell[TextData[ButtonBox["InterpolationMethodShepard",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/InterpolationMethodShepard"]], "Subsubsection",
 CellID->464443187],

Cell[TextData[ButtonBox["ShepardPower",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/ShepardPower"]], "TOCSection",
 CellID->63262075],

Cell[TextData[ButtonBox["InterpolationMethodVoronoi",
 BaseStyle->"Link",
 ButtonData->"paclet:Obtuse/ref/InterpolationMethodVoronoi"]], "Subsubsection",
 CellID->40633125],

Cell[CellGroupData[{

Cell["The Code", "Subsubsection",
 CellID->191560452],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], ";", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "cpvaluelist", "]"}], "\[LessEqual]", 
        RowBox[{"Length", "[", "pts", "]"}]}], ",", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"cpvaluelist", ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}]}], "]"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"cpnumber", ">", 
        RowBox[{"Length", "[", "pts", "]"}]}], ",", 
       RowBox[{"cpnumber", "=", 
        RowBox[{"Length", "[", "pts", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptsold", "=!=", "pts"}], ",", 
       RowBox[{
        RowBox[{"clsupdated", "=", "False"}], ";", 
        RowBox[{"Which", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "pts", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{"pts", "=", "ptsold"}], ",", 
          RowBox[{
           RowBox[{"Length", "[", "pts", "]"}], ">", 
           RowBox[{"Length", "[", "ptsold", "]"}]}], ",", 
          RowBox[{
           RowBox[{"cpnumber", "=", 
            RowBox[{"Length", "[", "pts", "]"}]}], ";", 
           RowBox[{"ptsold", "=", "pts"}]}], ",", 
          RowBox[{
           RowBox[{"Length", "[", "pts", "]"}], "<", 
           RowBox[{"Length", "[", "ptsold", "]"}]}], ",", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"pts", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "\[NotEqual]", 
               RowBox[{"ptsold", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"Do", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"cpvaluelist", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], "=", 
                  RowBox[{"cpvaluelist", "[", 
                   RowBox[{"[", 
                    RowBox[{"j", "+", "1"}], "]"}], "]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "i", ",", 
                   RowBox[{"Length", "[", "pts", "]"}]}], "}"}]}], "]"}], ";", 
               RowBox[{
                RowBox[{"cpvaluelist", "[", 
                 RowBox[{"[", 
                  RowBox[{"Length", "[", "ptsold", "]"}], "]"}], "]"}], "=", 
                RowBox[{"RandomReal", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}]}], ";", 
               RowBox[{"ptsold", "=", "pts"}], ";", 
               RowBox[{"cpnumber", "=", "1"}]}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Length", "[", "pts", "]"}]}], "}"}]}], "]"}], ",", 
          "True", ",", 
          RowBox[{"Catch", "[", 
           RowBox[{"Do", "[", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"pts", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[NotEqual]", 
                RowBox[{"ptsold", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"cpnumber", "=", "i"}], ";", 
                RowBox[{"ptsold", "=", "pts"}], ";", 
                RowBox[{"Throw", "[", "True", "]"}]}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", "pts", "]"}]}], "}"}]}], "]"}], "]"}]}],
          "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], ",", 
       RowBox[{
        RowBox[{"dm2", "=", 
         RowBox[{"DirectedDistanceMatrix", "[", 
          RowBox[{"pts", ",", 
           RowBox[{"DistanceFunction", "\[Rule]", 
            RowBox[{"dfunc", "[", "dfnum", "]"}]}]}], "]"}]}], ";", 
        RowBox[{"cls", "=", 
         RowBox[{"ConnectionList", "[", 
          RowBox[{"dm2", ",", 
           RowBox[{"CutoffRadius", "\[Rule]", "cutoffradius"}], ",", 
           RowBox[{"SmoothenDistance", "\[Rule]", "smoothendistance"}], ",", 
           RowBox[{"Type", "\[Rule]", "type"}], ",", 
           RowBox[{"NeighborLevel", "\[Rule]", "neighborlevel"}]}], "]"}]}], 
        ";", 
        RowBox[{"clsupdated", "=", "True"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"And", "[", 
        RowBox[{"Not", "[", 
         RowBox[{"And", "[", 
          RowBox[{
           RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], ",", 
           RowBox[{"interpolationorder", "\[Equal]", 
            RowBox[{"-", "1"}]}]}], "]"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Switch", "[", 
         RowBox[{"funcvals", ",", "1", ",", 
          RowBox[{"ptsf", "=", 
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"pts", ",", 
              RowBox[{
               RowBox[{"IdentityMatrix", "[", 
                RowBox[{"Length", "[", "pts", "]"}], "]"}], "[", 
               RowBox[{"[", "cpnumber", "]"}], "]"}]}], "}"}], "]"}]}], ",", 
          "2", ",", 
          RowBox[{"ptsf", "=", 
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"pts", ",", 
              RowBox[{"Take", "[", 
               RowBox[{"cpvaluelist", ",", 
                RowBox[{"Length", "[", "pts", "]"}]}], "]"}]}], "}"}], 
            "]"}]}], ",", "3", ",", 
          RowBox[{"ptsf", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"#", ",", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "]"}], "*", 
                RowBox[{"Sin", "[", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}], "&"}], "/@",
             "pts"}]}]}], "]"}], ";", 
        RowBox[{"func4", "=", 
         RowBox[{"Interpolation", "[", 
          RowBox[{"ptsf", ",", 
           RowBox[{"Method", "\[Rule]", "method"}], ",", 
           RowBox[{"CutoffRadius", "\[Rule]", "cutoffradius"}], ",", 
           RowBox[{"CutoffValue", "\[Rule]", "cutoffvalue"}], ",", 
           RowBox[{"DistanceFunction", "\[Rule]", 
            RowBox[{"dfunc", "[", "dfnum", "]"}]}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "interpolationorder"}], 
           ",", 
           RowBox[{"SmoothenDistance", "->", "smoothendistance"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"NeighborLevel", "->", "neighborlevel"}], ",", 
           RowBox[{"Type", "\[Rule]", "type"}], ",", 
           RowBox[{"RadialBasisFunction", "\[Rule]", 
            RowBox[{"rbffunc", "[", 
             RowBox[{"rbfnum", ",", "r0"}], "]"}]}], ",", 
           RowBox[{"ShepardPower", "\[Rule]", "sp"}]}], "]"}]}]}]}], "]"}], 
     ";", " ", 
     RowBox[{"Grid", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Pane", "[", 
          RowBox[{
           RowBox[{"Grid", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Green point number\>\"", ",", " ", 
                RowBox[{"Manipulator", "[", 
                 RowBox[{
                  RowBox[{"Dynamic", "[", "cpnumber", "]"}], ",", " ", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", 
                    RowBox[{"Length", "[", "pts", "]"}], ",", "1"}], "}"}], 
                  ",", 
                  RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{"InputField", "[", 
                 RowBox[{
                  RowBox[{"Dynamic", "[", "cpnumber", "]"}], ",", 
                  RowBox[{"FieldSize", "\[Rule]", "Tiny"}]}], "]"}]}], "}"}], 
              ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"And", "[", 
                   RowBox[{
                    RowBox[{"funcvals", "\[Equal]", "2"}], ",", 
                    RowBox[{"Not", "[", 
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], 
                    ",", 
                    RowBox[{"interpolationorder", "\[Equal]", 
                    RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<Green point\\nfunction value\>\"", ",", " ", 
                    RowBox[{"Manipulator", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"cpvaluelist", "[", 
                    RowBox[{"[", "cpnumber", "]"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
                    RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}],
                     ",", "\[IndentingNewLine]", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", 
                    RowBox[{"cpvaluelist", "[", 
                    RowBox[{"[", "cpnumber", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"FieldSize", "\[Rule]", "Tiny"}]}], "]"}]}], 
                   "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\< \\n \>\"", ",", 
                    RowBox[{"FontSize", "\[Rule]", "13"}]}], "]"}], "}"}]}], 
                 "]"}], "}"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"MemberQ", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Voronoi\>\"", ",", "\"\<ObtuseAngle\>\"", ",", 
                    "\"\<RBF\>\"", ",", "\"\<Shepard\>\""}], "}"}], ",", 
                    "method"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<Distance\\nFunction\>\"", ",", " ", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"dfnum", ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "\[Rule]", "\"\<Automatic\>\""}], ",", 
                    RowBox[{"2", "\[Rule]", "\"\<Periodic \\nsymmetric\>\""}],
                     ",", 
                    RowBox[{
                    "3", "\[Rule]", " ", "\"\<Periodic \\nasymmetric\>\""}], 
                    ",", 
                    RowBox[{
                    "4", "\[Rule]", "\"\<Cut with \\nasymmetry\>\""}]}], 
                    "}"}]}], "}"}], "]"}], ",", "SpanFromLeft"}], "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<CutoffRadius\>\"", ",", " ", 
                    RowBox[{"Manipulator", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "cutoffradius", "]"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "37"}], "}"}], ",", 
                    RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}],
                     ",", "\[IndentingNewLine]", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "cutoffradius", "]"}], ",", 
                    RowBox[{"FieldSize", "\[Rule]", "Tiny"}]}], "]"}]}], 
                   "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"And", "[", 
                   RowBox[{
                    RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], 
                    ",", 
                    RowBox[{"cutoffradius", "<", "36.002"}], ",", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
                    "interpolationorder"}], "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<CutoffValue\>\"", ",", " ", 
                    RowBox[{"Manipulator", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "cutoffvalue", "]"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
                    RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}],
                     ",", "\[IndentingNewLine]", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "cutoffvalue", "]"}], ",", 
                    RowBox[{"FieldSize", "\[Rule]", "Tiny"}]}], "]"}]}], 
                   "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\< \>\"", ",", 
                    RowBox[{"FontSize", "\[Rule]", "50"}]}], "]"}], "}"}]}], 
                 "]"}], "}"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<InterpolationOrder\>\"", ",", " ", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"interpolationorder", ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "1"}], "\[Rule]", 
                    "\"\< No interpolation \>\""}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"0", "\[Rule]", "\"\< 0 \>\""}], ",", 
                    RowBox[{"1", "\[Rule]", "\"\< 1 \>\""}], ",", 
                    RowBox[{"2", "\[Rule]", "\"\< 2 \>\""}], ",", 
                    RowBox[{"3", "\[Rule]", "\"\< 3 \>\""}]}], "}"}]}], "}"}],
                     "]"}], ",", "SpanFromLeft"}], "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<SmoothenDistance\>\"", ",", " ", 
                    RowBox[{"Manipulator", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "smoothendistance", "]"}], ",", 
                    " ", 
                    RowBox[{"{", 
                    RowBox[{"0.", ",", " ", "5"}], "}"}], ",", 
                    RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}],
                     ",", "\[IndentingNewLine]", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "smoothendistance", "]"}], ",", 
                    RowBox[{"FieldSize", "\[Rule]", "Tiny"}]}], "]"}]}], 
                   "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<NeighborLevel\>\"", ",", " ", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"neighborlevel", ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"1", " ", ",", "2", ",", "3", ",", "4"}], "}"}]}],
                     "}"}], "]"}], ",", "SpanFromLeft"}], "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<Type\>\"", ",", " ", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"type", ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directed", "\[Rule]", "\"\<Directed\>\""}], ",", 
                    RowBox[{"Undirected", "\[Rule]", "\"\<Undirected\>\""}]}],
                     "}"}]}], "}"}], "]"}], ",", "SpanFromLeft"}], "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<RBF\>\""}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<Radial\\nBasis\\nFunction\>\"", ",", " ", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"rbfnum", ",", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "\[Rule]", "\"\<Automatic\>\""}], ",", 
                    RowBox[{"2", "\[Rule]", "\"\<Multi\\nquadric\>\""}], ",", 
                    RowBox[{
                    "3", "\[Rule]", " ", 
                    "\"\<Inverse\\nMulti\\nquadric\>\""}], ",", 
                    RowBox[{"4", "\[Rule]", "\"\<Thin\\nPlate\\nSpline\>\""}],
                     ",", 
                    RowBox[{"5", "\[Rule]", "\"\<Gaussian\>\""}]}], "}"}]}], 
                    "}"}], "]"}], ",", "SpanFromLeft"}], "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"And", "[", 
                   RowBox[{
                    RowBox[{"method", "\[Equal]", "\"\<RBF\>\""}], ",", 
                    RowBox[{"rbfnum", ">", "1"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<r0\>\"", ",", " ", 
                    RowBox[{"Manipulator", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "r0", "]"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"0.01", ",", " ", "12."}], "}"}], ",", 
                    RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}],
                     ",", "\[IndentingNewLine]", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "r0", "]"}], ",", 
                    RowBox[{"FieldSize", "\[Rule]", "Tiny"}]}], "]"}]}], 
                   "}"}], ",", 
                  RowBox[{"{", "\"\< \>\"", "}"}]}], "]"}], "}"}]}], ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<Shepard\>\""}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<ShepardPower\>\"", ",", " ", 
                    RowBox[{"Manipulator", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "sp", "]"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", " ", "10"}], "}"}], ",", 
                    RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}],
                     ",", "\[IndentingNewLine]", 
                    RowBox[{"InputField", "[", 
                    RowBox[{
                    RowBox[{"Dynamic", "[", "sp", "]"}], ",", 
                    RowBox[{"FieldSize", "\[Rule]", "Tiny"}]}], "]"}], ",", 
                    "\"\<   \>\""}], "}"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"460", ",", "280"}], "}"}]}], "]"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"LocatorPane", "[", 
           RowBox[{
            RowBox[{"Dynamic", "[", "pts", "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"Not", "[", 
                   RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}], 
                    ",", 
                    RowBox[{"interpolationorder", "\[Equal]", 
                    RowBox[{"-", "1"}]}]}], "]"}], "]"}], ",", 
                  RowBox[{"ContourPlot", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"func4", "[", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y"}], "}"}], "]"}], "-", "0.0001"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"y", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"400", ",", "400"}], "}"}]}], ",", 
                    RowBox[{"Exclusions", "\[Rule]", "None"}]}], "]"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"And", "[", 
                 RowBox[{
                  RowBox[{"MemberQ", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"2", ",", "3"}], "}"}], ",", "dfnum"}], "]"}], 
                  ",", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Voronoi\>\"", ",", "\"\<ObtuseAngle\>\"", ",", 
                    "\"\<RBF\>\"", ",", "\"\<Shepard\>\""}], "}"}], ",", 
                    "method"}], "]"}]}], "]"}], ",", 
                RowBox[{"ListPlot", "[", 
                 RowBox[{
                  RowBox[{"Join", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], "&"}], "/@", " ", 
                    "pts"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", "0"}], "}"}]}], 
                    ")"}], "&"}], "/@", " ", "pts"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}]}], "}"}]}], ")"}], "&"}], 
                    "/@", " ", "pts"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], "+", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}]}], "}"}]}], ")"}], "&"}], 
                    "/@", "pts"}]}], "]"}], ",", 
                  RowBox[{"PlotStyle", "\[Rule]", 
                   RowBox[{"{", "Red", "}"}]}], ",", 
                  RowBox[{"ImageSize", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"400", ",", "400"}], "}"}]}], ",", 
                  RowBox[{"PlotRange", "->", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}]}], "}"}]}], ",", 
                  RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"ListPlot", "[", 
                 RowBox[{"pts", ",", 
                  RowBox[{"PlotStyle", "\[Rule]", 
                   RowBox[{"{", "Red", "}"}]}], ",", 
                  RowBox[{"ImageSize", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"400", ",", "400"}], "}"}]}], ",", 
                  RowBox[{"PlotRange", "->", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}]}], "}"}]}], ",", 
                  RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], "]"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"And", "[", 
                 RowBox[{
                  RowBox[{"MemberQ", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"2", ",", "3"}], "}"}], ",", "dfnum"}], "]"}], 
                  ",", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Voronoi\>\"", ",", "\"\<ObtuseAngle\>\"", ",", 
                    "\"\<RBF\>\"", ",", "\"\<Shepard\>\""}], "}"}], ",", 
                    "method"}], "]"}]}], "]"}], ",", 
                RowBox[{"Graphics", "[", 
                 RowBox[{"{", 
                  RowBox[{"Green", ",", 
                   RowBox[{"Disk", "[", 
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", "cpnumber", "]"}], "]"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], ",", "0.1"}], "]"}], 
                   ",", 
                   RowBox[{"Disk", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", "cpnumber", "]"}], "]"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", "0"}], "}"}]}], ",",
                     "0.1"}], "]"}], ",", 
                   RowBox[{"Disk", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", "cpnumber", "]"}], "]"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], "+", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}], ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}]}], "}"}]}], ",", "0.1"}], 
                    "]"}], ",", 
                   RowBox[{"Disk", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", "cpnumber", "]"}], "]"}], ",", 
                    RowBox[{"2", "*", "Pi"}]}], "]"}], "+", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "Pi"}]}], "}"}]}], ",", "0.1"}], 
                    "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{"Graphics", "[", 
                 RowBox[{"{", 
                  RowBox[{"Green", ",", 
                   RowBox[{"Disk", "[", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", "cpnumber", "]"}], "]"}], ",", "0.1"}], 
                    "]"}]}], "}"}], "]"}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"method", "\[Equal]", "\"\<Delaunay\>\""}], ",", 
                  RowBox[{"ListPlot", "[", 
                   RowBox[{
                    RowBox[{"Append", "[", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"ConvexHull", "[", "pts", "]"}], "]"}], "]"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"ConvexHull", "[", "pts", "]"}], "]"}], "]"}], 
                    "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", "White", "}"}]}]}], "]"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"And", "[", 
                   RowBox[{
                    RowBox[{"dfnum", "\[Equal]", "4"}], ",", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<Voronoi\>\"", ",", "\"\<ObtuseAngle\>\"", ",", 
                    "\"\<RBF\>\"", ",", "\"\<Shepard\>\""}], "}"}], ",", 
                    "method"}], "]"}]}], "]"}], ",", 
                  RowBox[{"Graphics", "[", 
                   RowBox[{"{", 
                    RowBox[{"Thick", ",", "Green", ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "2."}], ",", "0."}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
                   "]"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}], ",", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"{", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"And", "[", 
                   RowBox[{"clsupdated", ",", 
                    RowBox[{"method", "\[Equal]", "\"\<ObtuseAngle\>\""}]}], 
                   "]"}], ",", 
                  RowBox[{"Graphics", "[", 
                   RowBox[{"Which", "[", 
                    RowBox[{
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{"dfnum", "\[Equal]", "4"}], ",", 
                    RowBox[{"type", "===", "Undirected"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Which", "[", 
                    RowBox[{
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{"Or", "[", 
                    RowBox[{
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ">=", "0"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", "0"}]}], "]"}], ",", 
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ">=", "0"}]}], "]"}]}], 
                    "]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ")"}], "^", 
                    "2"}], "<", "4"}]}], "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "0"}], "}"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
                    "]"}], ",", "True", ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
                    "]"}]}], "]"}], "&"}], "/@", "cls"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{"dfnum", "\[Equal]", "4"}], ",", 
                    RowBox[{"type", "===", "Directed"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Which", "[", 
                    RowBox[{
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ">=", "0"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ")"}], "^", 
                    "2"}], "<", "4"}]}], "]"}], ",", 
                    RowBox[{"Arrow", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
                    "]"}], ",", 
                    RowBox[{"And", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ">=", "0"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ")"}], "^", 
                    "2"}], "<", "4"}]}], "]"}], ",", 
                    RowBox[{"Arrow", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"2", ",", "0"}], "}"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
                    "]"}], ",", "True", ",", 
                    RowBox[{"Arrow", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
                    "]"}]}], "]"}], "&"}], "/@", "cls"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"type", "===", "Undirected"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
                    "]"}], "&"}], "/@", "cls"}], "}"}], ",", "True", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Arrow", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"pts", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "}"}], 
                    "]"}], "&"}], "/@", "cls"}], "}"}]}], "]"}], "]"}], ",", 
                  RowBox[{"{", "}"}]}], "]"}], "}"}]}]}], "]"}], ",", 
            RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}], ",", 
            RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "]"}], ",", 
          "SpanFromLeft", ",", "SpanFromLeft"}], "}"}]}], "}"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"method", ",", "\"\<ObtuseAngle\>\"", ",", "\"\<Method\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Delaunay\>\"", ",", "\"\<Voronoi\>\"", ",", "\"\<ObtuseAngle\>\"",
         ",", "\"\<RBF\>\"", ",", "\"\<Shepard\>\""}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"funcvals", ",", "1", ",", "\"\<Function values\>\""}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "->", "\"\<Interpolation coefficients\>\""}], ",", 
        RowBox[{"2", "->", "\"\<Random adjustable\>\""}], ",", 
        RowBox[{"3", "->", "\"\<Sin[x]Sin[y]\>\""}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cpvaluelist", ",", 
        RowBox[{"RandomReal", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", "20", "}"}]}], "]"}]}], "}"}], ",", "None"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"pts", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2."}], ",", 
            RowBox[{"-", "2."}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.4", ",", 
            RowBox[{"-", "2.0"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.", ",", "2."}], "}"}]}], "}"}]}], "}"}], ",", "None"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cpnumber", ",", "1"}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cutoffradius", ",", "37."}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cutoffvalue", ",", "0."}], "}"}], ",", "None"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"interpolationorder", ",", "1"}], "}"}], ",", "None"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"dfnum", ",", "1"}], "}"}], ",", "None"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"smoothendistance", ",", "0."}], "}"}], ",", "None"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"neighborlevel", ",", "1"}], "}"}], ",", "None"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"type", ",", "Directed"}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r0", ",", "1."}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rbfnum", ",", "1"}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sp", ",", "6."}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"dm2", ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"cls", ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"ptsf", ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ptsold", ",", 
        RowBox[{"{", "}"}]}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"clsupdated", ",", "False"}], "}"}], ",", "None"}], "}"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"Button", "[", 
      RowBox[{"\"\<Generate a new point set!\>\"", ",", "randominit"}], 
      "]"}]}], ",", 
    RowBox[{"Initialization", ":>", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"AbortProtect", "[", 
        RowBox[{"Needs", "[", "\"\<Obtuse`\>\"", "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"randominit", ":=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"pts", "=", 
           RowBox[{"RandomReal", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "+", 
                RowBox[{"RandomInteger", "[", 
                 RowBox[{"PoissonDistribution", "[", "3.", "]"}], "]"}]}], 
               ",", "2"}], "}"}]}], "]"}]}], ";", 
          RowBox[{"cpnumber", "=", 
           RowBox[{"RandomInteger", "[", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"Length", "[", "pts", "]"}]}], "}"}], "]"}]}], ";", 
          RowBox[{"ptsold", "=", "pts"}], ";", 
          RowBox[{"cpvaluelist", "=", 
           RowBox[{"RandomReal", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
             RowBox[{"{", "20", "}"}]}], "]"}]}], ";", 
          RowBox[{"clsupdated", "=", "False"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dfunc", "[", "1", "]"}], ":=", "Automatic"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dfunc", "[", "2", "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"#2", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "-", 
                 RowBox[{"#1", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "2"}], "]"}], 
             "^", "2"}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"#2", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "-", 
                 RowBox[{"#1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}], "]"}], 
             "^", "2"}]}], ")"}], "&"}], ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dfunc", "[", "3", "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"#2", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "-", 
                  RowBox[{"#1", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "2"}], "+", 
               RowBox[{"0.5", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"#2", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "-", 
                  RowBox[{"#1", "[", 
                   RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "]"}], "^", 
             "2"}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"#2", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", 
                  RowBox[{"#1", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}], "+", 
               RowBox[{"0.5", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"#2", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", 
                  RowBox[{"#1", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "]"}], "^", 
             "2"}]}], ")"}], "&"}], ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dfunc", "[", "4", "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"And", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"#1", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ">=", "0"}], ",", 
              RowBox[{
               RowBox[{"#2", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ")"}], "^", 
                "2"}], "<", "4"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"EuclideanDistance", "[", 
                RowBox[{"#1", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "2"}], ",", "0"}], "}"}]}], "]"}], "+", 
               RowBox[{"EuclideanDistance", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", "#2"}], 
                "]"}]}], ")"}], "^", "2"}], ",", 
            RowBox[{"And", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"#1", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
              RowBox[{
               RowBox[{"#2", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ">=", "0"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ")"}], "^", 
                "2"}], "<", "4"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"EuclideanDistance", "[", 
                RowBox[{"#1", ",", 
                 RowBox[{"{", 
                  RowBox[{"2", ",", "0"}], "}"}]}], "]"}], "+", 
               RowBox[{"EuclideanDistance", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"2", ",", "0"}], "}"}], ",", "#2"}], "]"}]}], ")"}],
              "^", "2"}], ",", "True", ",", 
            RowBox[{"SquaredEuclideanDistance", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], "&"}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"rbffunc", "[", 
         RowBox[{"1", ",", "r_"}], "]"}], ":=", "Automatic"}], ";", 
       RowBox[{
        RowBox[{"rbffunc", "[", 
         RowBox[{"2", ",", "r_"}], "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"#", "+", 
             RowBox[{"r", "^", "2"}]}], "]"}], ")"}], "&"}], ")"}]}], ";", 
       RowBox[{
        RowBox[{"rbffunc", "[", 
         RowBox[{"3", ",", "r_"}], "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"#", "+", 
              RowBox[{"r", "^", "2"}]}], "]"}]}], ")"}], "&"}], ")"}]}], ";", 
       RowBox[{
        RowBox[{"rbffunc", "[", 
         RowBox[{"4", ",", "r_"}], "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"#", "\[Equal]", "0"}], ",", "0.", ",", 
            RowBox[{"#", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Log", "[", "#", "]"}], "/", "2"}], "-", 
               RowBox[{"Log", "[", "r", "]"}]}], ")"}]}]}], "]"}], "&"}], 
         ")"}]}], ";", 
       RowBox[{
        RowBox[{"rbffunc", "[", 
         RowBox[{"5", ",", "r_"}], "]"}], ":=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "#"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", 
               RowBox[{"r", "^", "2"}]}], ")"}]}], "]"}], ")"}], "&"}], 
         ")"}]}], ";"}], "\[IndentingNewLine]", "}"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[11]:=",
 CellID->22553827]
}, Closed]],

Cell[CellGroupData[{

Cell["RELATED TUTORIALS", "RelatedTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["Obtuse Angle Shadowing Networks",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Obtuse Angle Shadowing Networks"]], \
"RelatedTutorials",
 CellID->458632979],

Cell[TextData[ButtonBox["Scattered Point Interpolation",
 BaseStyle->"Link",
 ButtonData->
  "paclet:Obtuse/tutorial/Scattered Point Interpolation"]], "RelatedTutorials",
 CellID->806871991]
}, Open  ]],

Cell[CellGroupData[{

Cell["MORE ABOUT", "TutorialMoreAboutSection",
 CellID->23220180],

Cell[TextData[{
 "Copyright Ingolf Dahl 2010, ingolf.dahl@telia.com, ",
 ButtonBox["http://www.familydahl.se/mathematica",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.familydahl.se/mathematica"], None}]
}], "TutorialMoreAbout",
 CellID->78426474]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{736, 750},
WindowMargins->{{46, Automatic}, {25, Automatic}},
WindowTitle->"Interpolation interactive demo - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2010, 5, 20, 23, 19, 51.7694173}", "context" -> "Obtuse`", 
    "keywords" -> {
     "Obtuse Angle Shadowing", "Obtuse Angle", "Shadowing", 
      "Scattered Points", "n-dimensional", "Multidimensional", 
      "Interpolation", "Obtuse Angle Interpolation", "RBF", 
      "Radial Basis Function", "Shepard", "Delaunay", "distance-based"}, 
    "index" -> True, "label" -> "Obtuse Tutorial", "language" -> "en", 
    "paclet" -> "Obtuse", "status" -> "None", "summary" -> " ", 
    "synonyms" -> {}, "title" -> "Interpolation interactive demo", "type" -> 
    "Tutorial", "uri" -> "Obtuse/tutorial/Interpolation interactive demo"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"], 
   Cell[
    StyleData["TutorialMoreAboutSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["RelatedTutorialsSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["TutorialRelatedLinksSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}]}, Visible -> False, 
  FrontEndVersion -> "7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
   StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[611, 21, 78, 1, 3, "TutorialColorBar"],
Cell[692, 24, 178, 5, 19, "LinkTrail"],
Cell[873, 31, 2611, 59, 46, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[3509, 94, 67, 1, 51, "Title",
 CellID->509267359],
Cell[3579, 97, 3716, 75, 433, "ExampleText",
 CellID->10355336],
Cell[7298, 174, 27190, 560, 858, "Output",
 CellID->401249470],
Cell[34491, 736, 55, 1, 30, "Subsubsection",
 CellID->246703899],
Cell[34549, 739, 162, 3, 20, "TOCSection",
 CellID->122658320],
Cell[34714, 744, 145, 3, 20, "TOCSection",
 CellID->73792557],
Cell[34862, 749, 178, 4, 30, "Subsubsection",
 CellID->220643658],
Cell[35043, 755, 183, 4, 30, "Subsubsection",
 CellID->68061551],
Cell[35229, 761, 168, 3, 20, "TOCSection",
 CellID->190444796],
Cell[35400, 766, 142, 3, 20, "TOCSection",
 CellID->287698431],
Cell[35545, 771, 140, 3, 20, "TOCSection",
 CellID->146823888],
Cell[35688, 776, 143, 3, 20, "TOCSection",
 CellID->66198734],
Cell[35834, 781, 150, 3, 20, "TOCSection",
 CellID->160051397],
Cell[35987, 786, 125, 3, 20, "TOCSection",
 CellID->27883570],
Cell[36115, 791, 165, 3, 30, "Subsubsection",
 CellID->137838945],
Cell[36283, 796, 156, 3, 20, "TOCSection",
 CellID->452924850],
Cell[36442, 801, 173, 3, 30, "Subsubsection",
 CellID->464443187],
Cell[36618, 806, 141, 3, 20, "TOCSection",
 CellID->63262075],
Cell[36762, 811, 172, 3, 30, "Subsubsection",
 CellID->40633125],
Cell[CellGroupData[{
Cell[36959, 818, 53, 1, 30, "Subsubsection",
 CellID->191560452],
Cell[37015, 821, 61845, 1465, 2675, "Input",
 CellID->22553827]
}, Closed]],
Cell[CellGroupData[{
Cell[98897, 2291, 72, 1, 45, "RelatedTutorialsSection",
 CellID->415694126],
Cell[98972, 2294, 196, 5, 17, "RelatedTutorials",
 CellID->458632979],
Cell[99171, 2301, 190, 4, 17, "RelatedTutorials",
 CellID->806871991]
}, Open  ]],
Cell[CellGroupData[{
Cell[99398, 2310, 65, 1, 45, "TutorialMoreAboutSection",
 CellID->23220180],
Cell[99466, 2313, 264, 7, 17, "TutorialMoreAbout",
 CellID->78426474]
}, Open  ]]
}, Open  ]],
Cell[99757, 2324, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
